/**********************************************************************//**
* @file		AC33Mx064_hal_pcu.h
* @brief	Contains all macro definitions and function prototypes
* 			support for PCU firmware library on ac33mx064
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
************************************************************************
* ABOV Disclaimer
*
*IMPORTANT NOTICE ? PLEASE READ CAREFULLY
*ABOV Semiconductor ("ABOV") reserves the right to make changes, corrections, enhancements, 
*modifications, and improvements to ABOV products and/or to this document at any time without notice. 
*ABOV does not give warranties as to the accuracy or completeness of the information included herein.
*Purchasers should obtain the latest relevant information of ABOV products before placing orders. 
*Purchasers are entirely responsible for the choice, selection, and use of ABOV products and 
*ABOV assumes no liability for application assistance or the design of purchaser products. No license, 
*express or implied, to any intellectual property rights is granted by ABOV herein. 
*ABOV disclaims all express and implied warranties and shall not be responsible or
*liable for any injuries or damages related to use of ABOV products in such unauthorized applications. 
*ABOV and the ABOV logo are trademarks of ABOV.
*All other product or service names are the property of their respective owners. 
*Information in this document supersedes and replaces the information previously
*supplied in any former versions of this document.
*2020 ABOV Semiconductor  All rights reserved
*
**********************************************************************/

#ifndef _AC33MX064_PCU_H_
#define _AC33MX064_PCU_H_

/* Includes ------------------------------------------------------------------- */
#include "AC33Mx064.h"
#include "AC33Mx064_hal_aa_types.h"

#ifdef __cplusplus
extern "C"
{
#endif

/* Private macros ------------------------------------------------------------- */

#define PORT_ACCESS_EN()   do { PORTEN->EN=0x15; PORTEN->EN=0x51; } while(0)
#define PORT_ACCESS_DIS()  do { PORTEN->EN=0x00; } while(0) 

#define PCU_MR_FUNC_Msk                        (0x03UL)                            
#define PCU_CR_MODE_Msk                        (0x03UL)     

/* ================================================================================ */
/* ================          struct 'PCU' Position & Mask          ================ */
/* ================================================================================ */


/* -----------------------------------  PCU_MR  ----------------------------------- */
#define PCU_MR_P0_Pos                         0                                                       /*!< PCU MR: P0 Position                     */
#define PCU_MR_P0_Msk                         (0x03UL << PCU_MR_P0_Pos)                               /*!< PCU MR: P0 Mask                         */
#define PCU_MR_P1_Pos                         2                                                       /*!< PCU MR: P1 Position                     */
#define PCU_MR_P1_Msk                         (0x03UL << PCU_MR_P1_Pos)                               /*!< PCU MR: P1 Mask                         */
#define PCU_MR_P2_Pos                         4                                                       /*!< PCU MR: P2 Position                     */
#define PCU_MR_P2_Msk                         (0x03UL << PCU_MR_P2_Pos)                               /*!< PCU MR: P2 Mask                         */
#define PCU_MR_P3_Pos                         6                                                       /*!< PCU MR: P3 Position                     */
#define PCU_MR_P3_Msk                         (0x03UL << PCU_MR_P3_Pos)                               /*!< PCU MR: P3 Mask                         */
#define PCU_MR_P4_Pos                         8                                                       /*!< PCU MR: P4 Position                     */
#define PCU_MR_P4_Msk                         (0x03UL << PCU_MR_P4_Pos)                               /*!< PCU MR: P4 Mask                         */
#define PCU_MR_P5_Pos                         10                                                      /*!< PCU MR: P5 Position                     */
#define PCU_MR_P5_Msk                         (0x03UL << PCU_MR_P5_Pos)                               /*!< PCU MR: P5 Mask                         */
#define PCU_MR_P6_Pos                         12                                                      /*!< PCU MR: P6 Position                     */
#define PCU_MR_P6_Msk                         (0x03UL << PCU_MR_P6_Pos)                               /*!< PCU MR: P6 Mask                         */
#define PCU_MR_P7_Pos                         14                                                      /*!< PCU MR: P7 Position                     */
#define PCU_MR_P7_Msk                         (0x03UL << PCU_MR_P7_Pos)                               /*!< PCU MR: P7 Mask                         */
#define PCU_MR_P8_Pos                         16                                                      /*!< PCU MR: P8 Position                     */
#define PCU_MR_P8_Msk                         (0x03UL << PCU_MR_P8_Pos)                               /*!< PCU MR: P8 Mask                         */
#define PCU_MR_P9_Pos                         18                                                      /*!< PCU MR: P9 Position                     */
#define PCU_MR_P9_Msk                         (0x03UL << PCU_MR_P9_Pos)                               /*!< PCU MR: P9 Mask                         */
#define PCU_MR_P10_Pos                        20                                                      /*!< PCU MR: P10 Position                    */
#define PCU_MR_P10_Msk                        (0x03UL << PCU_MR_P10_Pos)                              /*!< PCU MR: P10 Mask                        */
#define PCU_MR_P11_Pos                        22                                                      /*!< PCU MR: P11 Position                    */
#define PCU_MR_P11_Msk                        (0x03UL << PCU_MR_P11_Pos)                              /*!< PCU MR: P11 Mask                        */
#define PCU_MR_P12_Pos                        24                                                      /*!< PCU MR: P12 Position                    */
#define PCU_MR_P12_Msk                        (0x03UL << PCU_MR_P12_Pos)                              /*!< PCU MR: P12 Mask                        */
#define PCU_MR_P13_Pos                        26                                                      /*!< PCU MR: P13 Position                    */
#define PCU_MR_P13_Msk                        (0x03UL << PCU_MR_P13_Pos)                              /*!< PCU MR: P13 Mask                        */
#define PCU_MR_P14_Pos                        28                                                      /*!< PCU MR: P14 Position                    */
#define PCU_MR_P14_Msk                        (0x03UL << PCU_MR_P14_Pos)                              /*!< PCU MR: P14 Mask                        */
#define PCU_MR_P15_Pos                        30                                                      /*!< PCU MR: P15 Position                    */
#define PCU_MR_P15_Msk                        (0x03UL << PCU_MR_P15_Pos)                              /*!< PCU MR: P15 Mask                        */

/* -----------------------------------  PCU_CR  ----------------------------------- */
#define PCU_CR_P0_Pos                         0                                                       /*!< PCU CR: P0 Position                     */
#define PCU_CR_P0_Msk                         (0x03UL << PCU_CR_P0_Pos)                               /*!< PCU CR: P0 Mask                         */
#define PCU_CR_P1_Pos                         2                                                       /*!< PCU CR: P1 Position                     */
#define PCU_CR_P1_Msk                         (0x03UL << PCU_CR_P1_Pos)                               /*!< PCU CR: P1 Mask                         */
#define PCU_CR_P2_Pos                         4                                                       /*!< PCU CR: P2 Position                     */
#define PCU_CR_P2_Msk                         (0x03UL << PCU_CR_P2_Pos)                               /*!< PCU CR: P2 Mask                         */
#define PCU_CR_P3_Pos                         6                                                       /*!< PCU CR: P3 Position                     */
#define PCU_CR_P3_Msk                         (0x03UL << PCU_CR_P3_Pos)                               /*!< PCU CR: P3 Mask                         */
#define PCU_CR_P4_Pos                         8                                                       /*!< PCU CR: P4 Position                     */
#define PCU_CR_P4_Msk                         (0x03UL << PCU_CR_P4_Pos)                               /*!< PCU CR: P4 Mask                         */
#define PCU_CR_P5_Pos                         10                                                      /*!< PCU CR: P5 Position                     */
#define PCU_CR_P5_Msk                         (0x03UL << PCU_CR_P5_Pos)                               /*!< PCU CR: P5 Mask                         */
#define PCU_CR_P6_Pos                         12                                                      /*!< PCU CR: P6 Position                     */
#define PCU_CR_P6_Msk                         (0x03UL << PCU_CR_P6_Pos)                               /*!< PCU CR: P6 Mask                         */
#define PCU_CR_P7_Pos                         14                                                      /*!< PCU CR: P7 Position                     */
#define PCU_CR_P7_Msk                         (0x03UL << PCU_CR_P7_Pos)                               /*!< PCU CR: P7 Mask                         */
#define PCU_CR_P8_Pos                         16                                                      /*!< PCU CR: P8 Position                     */
#define PCU_CR_P8_Msk                         (0x03UL << PCU_CR_P8_Pos)                               /*!< PCU CR: P8 Mask                         */
#define PCU_CR_P9_Pos                         18                                                      /*!< PCU CR: P9 Position                     */
#define PCU_CR_P9_Msk                         (0x03UL << PCU_CR_P9_Pos)                               /*!< PCU CR: P9 Mask                         */
#define PCU_CR_P10_Pos                        20                                                      /*!< PCU CR: P10 Position                    */
#define PCU_CR_P10_Msk                        (0x03UL << PCU_CR_P10_Pos)                              /*!< PCU CR: P10 Mask                        */
#define PCU_CR_P11_Pos                        22                                                      /*!< PCU CR: P11 Position                    */
#define PCU_CR_P11_Msk                        (0x03UL << PCU_CR_P11_Pos)                              /*!< PCU CR: P11 Mask                        */
#define PCU_CR_P12_Pos                        24                                                      /*!< PCU CR: P12 Position                    */
#define PCU_CR_P12_Msk                        (0x03UL << PCU_CR_P12_Pos)                              /*!< PCU CR: P12 Mask                        */
#define PCU_CR_P13_Pos                        26                                                      /*!< PCU CR: P13 Position                    */
#define PCU_CR_P13_Msk                        (0x03UL << PCU_CR_P13_Pos)                              /*!< PCU CR: P13 Mask                        */
#define PCU_CR_P14_Pos                        28                                                      /*!< PCU CR: P14 Position                    */
#define PCU_CR_P14_Msk                        (0x03UL << PCU_CR_P14_Pos)                              /*!< PCU CR: P14 Mask                        */
#define PCU_CR_P15_Pos                        30                                                      /*!< PCU CR: P15 Position                    */
#define PCU_CR_P15_Msk                        (0x03UL << PCU_CR_P15_Pos)                              /*!< PCU CR: P15 Mask                        */

/* -----------------------------------  PCU_PCR  ---------------------------------- */
#define PCU_PCR_P0_Pos                        0                                                       /*!< PCU PCR: P0 Position                    */
#define PCU_PCR_P0_Msk                        (0x01UL << PCU_PCR_P0_Pos)                              /*!< PCU PCR: P0 Mask                        */
#define PCU_PCR_P1_Pos                        1                                                       /*!< PCU PCR: P1 Position                    */
#define PCU_PCR_P1_Msk                        (0x01UL << PCU_PCR_P1_Pos)                              /*!< PCU PCR: P1 Mask                        */
#define PCU_PCR_P2_Pos                        2                                                       /*!< PCU PCR: P2 Position                    */
#define PCU_PCR_P2_Msk                        (0x01UL << PCU_PCR_P2_Pos)                              /*!< PCU PCR: P2 Mask                        */
#define PCU_PCR_P3_Pos                        3                                                       /*!< PCU PCR: P3 Position                    */
#define PCU_PCR_P3_Msk                        (0x01UL << PCU_PCR_P3_Pos)                              /*!< PCU PCR: P3 Mask                        */
#define PCU_PCR_P4_Pos                        4                                                       /*!< PCU PCR: P4 Position                    */
#define PCU_PCR_P4_Msk                        (0x01UL << PCU_PCR_P4_Pos)                              /*!< PCU PCR: P4 Mask                        */
#define PCU_PCR_P5_Pos                        5                                                       /*!< PCU PCR: P5 Position                    */
#define PCU_PCR_P5_Msk                        (0x01UL << PCU_PCR_P5_Pos)                              /*!< PCU PCR: P5 Mask                        */
#define PCU_PCR_P6_Pos                        6                                                       /*!< PCU PCR: P6 Position                    */
#define PCU_PCR_P6_Msk                        (0x01UL << PCU_PCR_P6_Pos)                              /*!< PCU PCR: P6 Mask                        */
#define PCU_PCR_P7_Pos                        7                                                       /*!< PCU PCR: P7 Position                    */
#define PCU_PCR_P7_Msk                        (0x01UL << PCU_PCR_P7_Pos)                              /*!< PCU PCR: P7 Mask                        */
#define PCU_PCR_P8_Pos                        8                                                       /*!< PCU PCR: P8 Position                    */
#define PCU_PCR_P8_Msk                        (0x01UL << PCU_PCR_P8_Pos)                              /*!< PCU PCR: P8 Mask                        */
#define PCU_PCR_P9_Pos                        9                                                       /*!< PCU PCR: P9 Position                    */
#define PCU_PCR_P9_Msk                        (0x01UL << PCU_PCR_P9_Pos)                              /*!< PCU PCR: P9 Mask                        */
#define PCU_PCR_P10_Pos                       10                                                      /*!< PCU PCR: P10 Position                   */
#define PCU_PCR_P10_Msk                       (0x01UL << PCU_PCR_P10_Pos)                             /*!< PCU PCR: P10 Mask                       */
#define PCU_PCR_P11_Pos                       11                                                      /*!< PCU PCR: P11 Position                   */
#define PCU_PCR_P11_Msk                       (0x01UL << PCU_PCR_P11_Pos)                             /*!< PCU PCR: P11 Mask                       */
#define PCU_PCR_P12_Pos                       12                                                      /*!< PCU PCR: P12 Position                   */
#define PCU_PCR_P12_Msk                       (0x01UL << PCU_PCR_P12_Pos)                             /*!< PCU PCR: P12 Mask                       */
#define PCU_PCR_P13_Pos                       13                                                      /*!< PCU PCR: P13 Position                   */
#define PCU_PCR_P13_Msk                       (0x01UL << PCU_PCR_P13_Pos)                             /*!< PCU PCR: P13 Mask                       */
#define PCU_PCR_P14_Pos                       14                                                      /*!< PCU PCR: P14 Position                   */
#define PCU_PCR_P14_Msk                       (0x01UL << PCU_PCR_P14_Pos)                             /*!< PCU PCR: P14 Mask                       */
#define PCU_PCR_P15_Pos                       15                                                      /*!< PCU PCR: P15 Position                   */
#define PCU_PCR_P15_Msk                       (0x01UL << PCU_PCR_P15_Pos)                             /*!< PCU PCR: P15 Mask                       */

/* -----------------------------------  PCU_DER  ---------------------------------- */
#define PCU_DER_P0_Pos                        0                                                       /*!< PCU DER: P0 Position                    */
#define PCU_DER_P0_Msk                        (0x01UL << PCU_DER_P0_Pos)                              /*!< PCU DER: P0 Mask                        */
#define PCU_DER_P1_Pos                        1                                                       /*!< PCU DER: P1 Position                    */
#define PCU_DER_P1_Msk                        (0x01UL << PCU_DER_P1_Pos)                              /*!< PCU DER: P1 Mask                        */
#define PCU_DER_P2_Pos                        2                                                       /*!< PCU DER: P2 Position                    */
#define PCU_DER_P2_Msk                        (0x01UL << PCU_DER_P2_Pos)                              /*!< PCU DER: P2 Mask                        */
#define PCU_DER_P3_Pos                        3                                                       /*!< PCU DER: P3 Position                    */
#define PCU_DER_P3_Msk                        (0x01UL << PCU_DER_P3_Pos)                              /*!< PCU DER: P3 Mask                        */
#define PCU_DER_P4_Pos                        4                                                       /*!< PCU DER: P4 Position                    */
#define PCU_DER_P4_Msk                        (0x01UL << PCU_DER_P4_Pos)                              /*!< PCU DER: P4 Mask                        */
#define PCU_DER_P5_Pos                        5                                                       /*!< PCU DER: P5 Position                    */
#define PCU_DER_P5_Msk                        (0x01UL << PCU_DER_P5_Pos)                              /*!< PCU DER: P5 Mask                        */
#define PCU_DER_P6_Pos                        6                                                       /*!< PCU DER: P6 Position                    */
#define PCU_DER_P6_Msk                        (0x01UL << PCU_DER_P6_Pos)                              /*!< PCU DER: P6 Mask                        */
#define PCU_DER_P7_Pos                        7                                                       /*!< PCU DER: P7 Position                    */
#define PCU_DER_P7_Msk                        (0x01UL << PCU_DER_P7_Pos)                              /*!< PCU DER: P7 Mask                        */
#define PCU_DER_P8_Pos                        8                                                       /*!< PCU DER: P8 Position                    */
#define PCU_DER_P8_Msk                        (0x01UL << PCU_DER_P8_Pos)                              /*!< PCU DER: P8 Mask                        */
#define PCU_DER_P9_Pos                        9                                                       /*!< PCU DER: P9 Position                    */
#define PCU_DER_P9_Msk                        (0x01UL << PCU_DER_P9_Pos)                              /*!< PCU DER: P9 Mask                        */
#define PCU_DER_P10_Pos                       10                                                      /*!< PCU DER: P10 Position                   */
#define PCU_DER_P10_Msk                       (0x01UL << PCU_DER_P10_Pos)                             /*!< PCU DER: P10 Mask                       */
#define PCU_DER_P11_Pos                       11                                                      /*!< PCU DER: P11 Position                   */
#define PCU_DER_P11_Msk                       (0x01UL << PCU_DER_P11_Pos)                             /*!< PCU DER: P11 Mask                       */
#define PCU_DER_P12_Pos                       12                                                      /*!< PCU DER: P12 Position                   */
#define PCU_DER_P12_Msk                       (0x01UL << PCU_DER_P12_Pos)                             /*!< PCU DER: P12 Mask                       */
#define PCU_DER_P13_Pos                       13                                                      /*!< PCU DER: P13 Position                   */
#define PCU_DER_P13_Msk                       (0x01UL << PCU_DER_P13_Pos)                             /*!< PCU DER: P13 Mask                       */
#define PCU_DER_P14_Pos                       14                                                      /*!< PCU DER: P14 Position                   */
#define PCU_DER_P14_Msk                       (0x01UL << PCU_DER_P14_Pos)                             /*!< PCU DER: P14 Mask                       */
#define PCU_DER_P15_Pos                       15                                                      /*!< PCU DER: P15 Position                   */
#define PCU_DER_P15_Msk                       (0x01UL << PCU_DER_P15_Pos)                             /*!< PCU DER: P15 Mask                       */

/* -----------------------------------  PCU_IER  ---------------------------------- */
#define PCU_IER_P0_Pos                        0                                                       /*!< PCU IER: P0 Position                    */
#define PCU_IER_P0_Msk                        (0x03UL << PCU_IER_P0_Pos)                              /*!< PCU IER: P0 Mask                        */
#define PCU_IER_P1_Pos                        2                                                       /*!< PCU IER: P1 Position                    */
#define PCU_IER_P1_Msk                        (0x03UL << PCU_IER_P1_Pos)                              /*!< PCU IER: P1 Mask                        */
#define PCU_IER_P2_Pos                        4                                                       /*!< PCU IER: P2 Position                    */
#define PCU_IER_P2_Msk                        (0x03UL << PCU_IER_P2_Pos)                              /*!< PCU IER: P2 Mask                        */
#define PCU_IER_P3_Pos                        6                                                       /*!< PCU IER: P3 Position                    */
#define PCU_IER_P3_Msk                        (0x03UL << PCU_IER_P3_Pos)                              /*!< PCU IER: P3 Mask                        */
#define PCU_IER_P4_Pos                        8                                                       /*!< PCU IER: P4 Position                    */
#define PCU_IER_P4_Msk                        (0x03UL << PCU_IER_P4_Pos)                              /*!< PCU IER: P4 Mask                        */
#define PCU_IER_P5_Pos                        10                                                      /*!< PCU IER: P5 Position                    */
#define PCU_IER_P5_Msk                        (0x03UL << PCU_IER_P5_Pos)                              /*!< PCU IER: P5 Mask                        */
#define PCU_IER_P6_Pos                        12                                                      /*!< PCU IER: P6 Position                    */
#define PCU_IER_P6_Msk                        (0x03UL << PCU_IER_P6_Pos)                              /*!< PCU IER: P6 Mask                        */
#define PCU_IER_P7_Pos                        14                                                      /*!< PCU IER: P7 Position                    */
#define PCU_IER_P7_Msk                        (0x03UL << PCU_IER_P7_Pos)                              /*!< PCU IER: P7 Mask                        */
#define PCU_IER_P8_Pos                        16                                                      /*!< PCU IER: P8 Position                    */
#define PCU_IER_P8_Msk                        (0x03UL << PCU_IER_P8_Pos)                              /*!< PCU IER: P8 Mask                        */
#define PCU_IER_P9_Pos                        18                                                      /*!< PCU IER: P9 Position                    */
#define PCU_IER_P9_Msk                        (0x03UL << PCU_IER_P9_Pos)                              /*!< PCU IER: P9 Mask                        */
#define PCU_IER_P10_Pos                       20                                                      /*!< PCU IER: P10 Position                   */
#define PCU_IER_P10_Msk                       (0x03UL << PCU_IER_P10_Pos)                             /*!< PCU IER: P10 Mask                       */
#define PCU_IER_P11_Pos                       22                                                      /*!< PCU IER: P11 Position                   */
#define PCU_IER_P11_Msk                       (0x03UL << PCU_IER_P11_Pos)                             /*!< PCU IER: P11 Mask                       */
#define PCU_IER_P12_Pos                       24                                                      /*!< PCU IER: P12 Position                   */
#define PCU_IER_P12_Msk                       (0x03UL << PCU_IER_P12_Pos)                             /*!< PCU IER: P12 Mask                       */
#define PCU_IER_P13_Pos                       26                                                      /*!< PCU IER: P13 Position                   */
#define PCU_IER_P13_Msk                       (0x03UL << PCU_IER_P13_Pos)                             /*!< PCU IER: P13 Mask                       */
#define PCU_IER_P14_Pos                       28                                                      /*!< PCU IER: P14 Position                   */
#define PCU_IER_P14_Msk                       (0x03UL << PCU_IER_P14_Pos)                             /*!< PCU IER: P14 Mask                       */
#define PCU_IER_P15_Pos                       30                                                      /*!< PCU IER: P15 Position                   */
#define PCU_IER_P15_Msk                       (0x03UL << PCU_IER_P15_Pos)                             /*!< PCU IER: P15 Mask                       */

/* -----------------------------------  PCU_ISR  ---------------------------------- */
#define PCU_ISR_P0_Pos                        0                                                       /*!< PCU ISR: P0 Position                    */
#define PCU_ISR_P0_Msk                        (0x03UL << PCU_ISR_P0_Pos)                              /*!< PCU ISR: P0 Mask                        */
#define PCU_ISR_P1_Pos                        2                                                       /*!< PCU ISR: P1 Position                    */
#define PCU_ISR_P1_Msk                        (0x03UL << PCU_ISR_P1_Pos)                              /*!< PCU ISR: P1 Mask                        */
#define PCU_ISR_P2_Pos                        4                                                       /*!< PCU ISR: P2 Position                    */
#define PCU_ISR_P2_Msk                        (0x03UL << PCU_ISR_P2_Pos)                              /*!< PCU ISR: P2 Mask                        */
#define PCU_ISR_P3_Pos                        6                                                       /*!< PCU ISR: P3 Position                    */
#define PCU_ISR_P3_Msk                        (0x03UL << PCU_ISR_P3_Pos)                              /*!< PCU ISR: P3 Mask                        */
#define PCU_ISR_P4_Pos                        8                                                       /*!< PCU ISR: P4 Position                    */
#define PCU_ISR_P4_Msk                        (0x03UL << PCU_ISR_P4_Pos)                              /*!< PCU ISR: P4 Mask                        */
#define PCU_ISR_P5_Pos                        10                                                      /*!< PCU ISR: P5 Position                    */
#define PCU_ISR_P5_Msk                        (0x03UL << PCU_ISR_P5_Pos)                              /*!< PCU ISR: P5 Mask                        */
#define PCU_ISR_P6_Pos                        12                                                      /*!< PCU ISR: P6 Position                    */
#define PCU_ISR_P6_Msk                        (0x03UL << PCU_ISR_P6_Pos)                              /*!< PCU ISR: P6 Mask                        */
#define PCU_ISR_P7_Pos                        14                                                      /*!< PCU ISR: P7 Position                    */
#define PCU_ISR_P7_Msk                        (0x03UL << PCU_ISR_P7_Pos)                              /*!< PCU ISR: P7 Mask                        */
#define PCU_ISR_P8_Pos                        16                                                      /*!< PCU ISR: P8 Position                    */
#define PCU_ISR_P8_Msk                        (0x03UL << PCU_ISR_P8_Pos)                              /*!< PCU ISR: P8 Mask                        */
#define PCU_ISR_P9_Pos                        18                                                      /*!< PCU ISR: P9 Position                    */
#define PCU_ISR_P9_Msk                        (0x03UL << PCU_ISR_P9_Pos)                              /*!< PCU ISR: P9 Mask                        */
#define PCU_ISR_P10_Pos                       20                                                      /*!< PCU ISR: P10 Position                   */
#define PCU_ISR_P10_Msk                       (0x03UL << PCU_ISR_P10_Pos)                             /*!< PCU ISR: P10 Mask                       */
#define PCU_ISR_P11_Pos                       22                                                      /*!< PCU ISR: P11 Position                   */
#define PCU_ISR_P11_Msk                       (0x03UL << PCU_ISR_P11_Pos)                             /*!< PCU ISR: P11 Mask                       */
#define PCU_ISR_P12_Pos                       24                                                      /*!< PCU ISR: P12 Position                   */
#define PCU_ISR_P12_Msk                       (0x03UL << PCU_ISR_P12_Pos)                             /*!< PCU ISR: P12 Mask                       */
#define PCU_ISR_P13_Pos                       26                                                      /*!< PCU ISR: P13 Position                   */
#define PCU_ISR_P13_Msk                       (0x03UL << PCU_ISR_P13_Pos)                             /*!< PCU ISR: P13 Mask                       */
#define PCU_ISR_P14_Pos                       28                                                      /*!< PCU ISR: P14 Position                   */
#define PCU_ISR_P14_Msk                       (0x03UL << PCU_ISR_P14_Pos)                             /*!< PCU ISR: P14 Mask                       */
#define PCU_ISR_P15_Pos                       30                                                      /*!< PCU ISR: P15 Position                   */
#define PCU_ISR_P15_Msk                       (0x03UL << PCU_ISR_P15_Pos)                             /*!< PCU ISR: P15 Mask                       */

/* -----------------------------------  PCU_ICR  ---------------------------------- */
#define PCU_ICR_P0_Pos                        0                                                       /*!< PCU ICR: P0 Position                    */
#define PCU_ICR_P0_Msk                        (0x03UL << PCU_ICR_P0_Pos)                              /*!< PCU ICR: P0 Mask                        */
#define PCU_ICR_P1_Pos                        2                                                       /*!< PCU ICR: P1 Position                    */
#define PCU_ICR_P1_Msk                        (0x03UL << PCU_ICR_P1_Pos)                              /*!< PCU ICR: P1 Mask                        */
#define PCU_ICR_P2_Pos                        4                                                       /*!< PCU ICR: P2 Position                    */
#define PCU_ICR_P2_Msk                        (0x03UL << PCU_ICR_P2_Pos)                              /*!< PCU ICR: P2 Mask                        */
#define PCU_ICR_P3_Pos                        6                                                       /*!< PCU ICR: P3 Position                    */
#define PCU_ICR_P3_Msk                        (0x03UL << PCU_ICR_P3_Pos)                              /*!< PCU ICR: P3 Mask                        */
#define PCU_ICR_P4_Pos                        8                                                       /*!< PCU ICR: P4 Position                    */
#define PCU_ICR_P4_Msk                        (0x03UL << PCU_ICR_P4_Pos)                              /*!< PCU ICR: P4 Mask                        */
#define PCU_ICR_P5_Pos                        10                                                      /*!< PCU ICR: P5 Position                    */
#define PCU_ICR_P5_Msk                        (0x03UL << PCU_ICR_P5_Pos)                              /*!< PCU ICR: P5 Mask                        */
#define PCU_ICR_P6_Pos                        12                                                      /*!< PCU ICR: P6 Position                    */
#define PCU_ICR_P6_Msk                        (0x03UL << PCU_ICR_P6_Pos)                              /*!< PCU ICR: P6 Mask                        */
#define PCU_ICR_P7_Pos                        14                                                      /*!< PCU ICR: P7 Position                    */
#define PCU_ICR_P7_Msk                        (0x03UL << PCU_ICR_P7_Pos)                              /*!< PCU ICR: P7 Mask                        */
#define PCU_ICR_P8_Pos                        16                                                      /*!< PCU ICR: P8 Position                    */
#define PCU_ICR_P8_Msk                        (0x03UL << PCU_ICR_P8_Pos)                              /*!< PCU ICR: P8 Mask                        */
#define PCU_ICR_P9_Pos                        18                                                      /*!< PCU ICR: P9 Position                    */
#define PCU_ICR_P9_Msk                        (0x03UL << PCU_ICR_P9_Pos)                              /*!< PCU ICR: P9 Mask                        */
#define PCU_ICR_P10_Pos                       20                                                      /*!< PCU ICR: P10 Position                   */
#define PCU_ICR_P10_Msk                       (0x03UL << PCU_ICR_P10_Pos)                             /*!< PCU ICR: P10 Mask                       */
#define PCU_ICR_P11_Pos                       22                                                      /*!< PCU ICR: P11 Position                   */
#define PCU_ICR_P11_Msk                       (0x03UL << PCU_ICR_P11_Pos)                             /*!< PCU ICR: P11 Mask                       */
#define PCU_ICR_P12_Pos                       24                                                      /*!< PCU ICR: P12 Position                   */
#define PCU_ICR_P12_Msk                       (0x03UL << PCU_ICR_P12_Pos)                             /*!< PCU ICR: P12 Mask                       */
#define PCU_ICR_P13_Pos                       26                                                      /*!< PCU ICR: P13 Position                   */
#define PCU_ICR_P13_Msk                       (0x03UL << PCU_ICR_P13_Pos)                             /*!< PCU ICR: P13 Mask                       */
#define PCU_ICR_P14_Pos                       28                                                      /*!< PCU ICR: P14 Position                   */
#define PCU_ICR_P14_Msk                       (0x03UL << PCU_ICR_P14_Pos)                             /*!< PCU ICR: P14 Mask                       */
#define PCU_ICR_P15_Pos                       30                                                      /*!< PCU ICR: P15 Position                   */
#define PCU_ICR_P15_Msk                       (0x03UL << PCU_ICR_P15_Pos)                             /*!< PCU ICR: P15 Mask                       */



/* Pin function */
#define FUNC0 			0x0				/** Function 0 	*/
#define FUNC1 			0x1				/** Function 1 	*/
#define FUNC2 			0x2				/** Function 2	*/
#define FUNC3 			0x3				/** Function 3	*/

//==========================================================================
// 	PAMR
//==========================================================================
#define PA0_MUX_PA0							(0)
#define PA0_MUX_AN0							(3)

#define PA1_MUX_PA1							(0)
#define PA1_MUX_AN1							(3)

#define PA2_MUX_PA2							(0)
#define PA2_MUX_AN2							(3)

#define PA3_MUX_PA3							(0)
#define PA3_MUX_AN3							(3)

#define PA4_MUX_PA4							(0)
#define PA4_MUX_SS1							(1)
#define PA4_MUX_T0O							(2)
#define PA4_MUX_AN4							(3)

#define PA5_MUX_PA5							(0)
#define PA5_MUX_SS2							(1)
#define PA5_MUX_T1O							(2)
#define PA5_MUX_AN5							(3)

#define PA6_MUX_PA6							(0)
#define PA6_MUX_T0IO						(1)
#define PA6_MUX_T2O							(2)
#define PA6_MUX_AN6							(3)

#define PA7_MUX_PA7							(0)
#define PA7_MUX_T1IO						(1)
#define PA7_MUX_T3O							(2)
#define PA7_MUX_AN7							(3)

#define PA8_MUX_PA8							(0)
#define PA8_MUX_T2IO						(1)
#define PA8_MUX_AD0O						(2)
#define PA8_MUX_AN8							(3)

#define PA9_MUX_PA9							(0)
#define PA9_MUX_T3IO						(1)
#define PA9_MUX_AD1O						(2)
#define PA9_MUX_AN9							(3)

#define PA10_MUX_PA10					(0)
#define PA10_MUX_SS3					(1)
#define PA10_MUX_AD2O					(2)
#define PA10_MUX_AN10					(3)

#define PA11_MUX_PA11					(0)
#define PA11_MUX_AN11					(3)

#define PA12_MUX_PA12					(0)
#define PA12_MUX_T0IO					(1)
#define PA12_MUX_AN12					(3)

#define PA13_MUX_PA13					(0)
#define PA13_MUX_T1IO					(1)
#define PA13_MUX_AN13					(3)

#define PA14_MUX_PA14					(0)
#define PA14_MUX_T2IO					(1)
#define PA14_MUX_AN14					(3)

#define PA15_MUX_PA15					(0)
#define PA15_MUX_T3IO					(1)
#define PA15_MUX_AN15					(3)

//==========================================================================
// 	PBMR
//==========================================================================
#define PB0_MUX_PB0							(0)
#define PB0_MUX_MPWM0UH		(1)

#define PB1_MUX_PB1							(0)
#define PB1_MUX_MPWM0UL		(1)

#define PB2_MUX_PB2							(0)
#define PB2_MUX_MPWM0VH		(1)				

#define PB3_MUX_PB3							(0)
#define PB3_MUX_MPWM0VL		(1)				

#define PB4_MUX_PB4							(0)
#define PB4_MUX_MPWM0WH		(1)

#define PB5_MUX_PB5							(0)
#define PB5_MUX_MPWM0WL		(1)

#define PB6_MUX_PB6							(0)
#define PB6_MUX_PRTIN0					(1)
#define PB6_MUX_T0IO						(2)

#define PB7_MUX_PB7							(0)
#define PB7_MUX_OVIN0 					(1)
#define PB7_MUX_T1IO					(2)


//==========================================================================
// 	PCMR
//		
//
//==========================================================================
#define PC0_MUX_PC0							(0)
#define PC0_MUX_TCK							(1)				
#define PC0_MUX_SWCLK					(1)
#define PC0_MUX_RXD1					(2)

#define PC1_MUX_PC1							(0)
#define PC1_MUX_TMS							(1)			
#define PC1_MUX_SWDIO					(1)
#define PC1_MUX_TXD1					(2)

#define PC2_MUX_PC2							(0)
#define PC2_MUX_TDO							(1)				
#define PC2_MUX_SWO							(1)
#define PC2_MUX_T8IO						(2)

#define PC3_MUX_PC3							(0)
#define PC3_MUX_TDI								(1)				
#define PC3_MUX_T9IO							(2)	

#define PC4_MUX_PC4							(0)
#define PC4_MUX_nTRST					(1)
#define PC4_MUX_T0IO								(2)

#define PC5_MUX_PC5							(0)
#define PC5_MUX_RXD1						(1)
#define PC5_MUX_TIO								(2)

#define PC6_MUX_PC6							(0)
#define PC6_MUX_TXD1							(1)
#define PC6_MUX_T2IO							(2)

#define PC7_MUX_PC7							(0)
#define PC7_MUX_SCL0							(1)
#define PC7_MUX_T3IO							(2)

#define PC8_MUX_PC8							(0)
#define PC8_MUX_SDA0						(1)

#define PC9_MUX_PC9							(0)
#define PC9_MUX_CLKO						(1)

#define PC10_MUX_PC10						(0)
#define PC10_MUX_nRESET			(1)
#define PC10_MUX_T8IO      			(2)

#define PC11_MUX_PC11						(0)
#define PC11_MUX_T9IO 						(2)

#define PC12_MUX_PC12						(0)
#define PC12_MUX_XIN							(3)

#define PC13_MUX_PC13						(0)
#define PC13_MUX_XOUT					(3)

#define PC14_MUX_PC14						(0)
#define PC14_MUX_RXD0						(1)
#define PC14_MUX_MISO0					(2)

#define PC15_MUX_PC15						(0)
#define PC15_MUX_TXD0						(1)
#define PC15_MUX_MOSI0						(2)

//==========================================================================
// 	PDMR
//==========================================================================
#define PD0_MUX_PD0							(0)
#define PD0_MUX_SS0							(1)				
#define PD0_MUX_T8IO							(2)	

#define PD1_MUX_PD1							(0)
#define PD1_MUX_SCK0						(1)			
#define PD1_MUX_T9IO						(2)	

#define PD2_MUX_PD2							(0)
#define PD2_MUX_MOSI0						(1)				
#define PD2_MUX_SCL0						(2)		

#define PD3_MUX_PD3							(0)
#define PD3_MUX_MISO0						(1)				
#define PD3_MUX_SDA0						(2)		

/*
 * @brief 	PCU port mode enumerate definition
 */
typedef enum {
	PUSH_PULL_OUTPUT = 0,
	OPEN_DRAIN_OUTPUT,
	INPUT,
	ANALOG
}PCU_PORT_MODE;

enum {
	IER_DISABLE = 0,
	IER_LEVEL,
	IER_EDGE = 3
};

enum {
	ICR_PROHIBIT_INT = 0,
	ICR_LOW_LEVEL_INT = 1,
	ICR_FALLING_EDGE_INT = ICR_LOW_LEVEL_INT,
	ICR_HIGH_LEVEL_INT =2,
	ICR_RISING_EDGE_INT = ICR_HIGH_LEVEL_INT,
	ICR_BOTH_EDGE_INT =3	
};


/* Public Functions ----------------------------------------------------------- */
void HAL_GPIO_ConfigureFunction(PCU_Type *PCx, uint8_t pin_no, uint32_t func);
void HAL_GPIO_ConfigOutput(PCU_Type *PCx, uint8_t pin_no, PCU_PORT_MODE dir_type);
void HAL_GPIO_ConfigPullup(PCU_Type *PCx, uint8_t pin_no, FunctionalState pullup);

void HAL_GPIO_EXTI_Config(PCU_Type *PCx, uint8_t pin_no, uint8_t pin_en, uint8_t int_mode);
uint32_t HAL_GPIO_EXTI_GetStatus(PCU_Type *PCx);
void HAL_GPIO_EXTI_ClearPin(PCU_Type *PCx, uint32_t value);

void HAL_GPIO_SetDebouncePin(PCU_Type *PCx, uint8_t pin_no, FunctionalState debounce);

void HAL_GPIO_SetPin(GPIO_Type *Px, uint16_t bitValue);
void HAL_GPIO_ClearPin(GPIO_Type *Px, uint16_t bitValue);
uint16_t HAL_GPIO_ReadPin(GPIO_Type *Px);
void HAL_GPIO_WritePin(GPIO_Type *Px, uint16_t Value);

#ifdef __cplusplus
}
#endif

#endif /* end _AC33MX064_PCU_H_ */

/* --------------------------------- End Of File ------------------------------ */
