/**********************************************************************//**
* @file		AC33Mx064_hal_scu.h
* @brief	Contains all macro definitions and function prototypes
* 			support for SCU firmware library on AC33Mx064
* @version	1.00
* @date		
* @author	ABOV M team
*
* Copyright(C) 2019, ABOV Semiconductor
* All rights reserved.
*
************************************************************************
* ABOV Disclaimer
*
*IMPORTANT NOTICE ? PLEASE READ CAREFULLY
*ABOV Semiconductor ("ABOV") reserves the right to make changes, corrections, enhancements, 
*modifications, and improvements to ABOV products and/or to this document at any time without notice. 
*ABOV does not give warranties as to the accuracy or completeness of the information included herein.
*Purchasers should obtain the latest relevant information of ABOV products before placing orders. 
*Purchasers are entirely responsible for the choice, selection, and use of ABOV products and 
*ABOV assumes no liability for application assistance or the design of purchaser products. No license, 
*express or implied, to any intellectual property rights is granted by ABOV herein. 
*ABOV disclaims all express and implied warranties and shall not be responsible or
*liable for any injuries or damages related to use of ABOV products in such unauthorized applications. 
*ABOV and the ABOV logo are trademarks of ABOV.
*All other product or service names are the property of their respective owners. 
*Information in this document supersedes and replaces the information previously
*supplied in any former versions of this document.
*2020 ABOV Semiconductor  All rights reserved
*
**********************************************************************/

#ifndef _AC33MX064_SCU_H_
#define _AC33MX064_SCU_H_

/* Includes ------------------------------------------------------------------- */
#include "AC33Mx064.h"
#include "AC33Mx064_hal_aa_types.h"



/* Private macros ------------------------------------------------------------- */
/* ================================================================================ */
/* ================          struct 'SCU' Position & Mask          ================ */
/* ================================================================================ */


/* -----------------------------------  SCU_SMR  ---------------------------------- */
#define SCU_SMR_PREVMODE_Pos                  4                                                       /*!< SCU SMR: PREVMODE Position              */
#define SCU_SMR_PREVMODE_Msk                  (0x03UL << SCU_SMR_PREVMODE_Pos)                        /*!< SCU SMR: PREVMODE Mask                  */
#define SCU_SMR_VDCAON_Pos                    8                                                       /*!< SCU SMR: VDCAON Position                */
#define SCU_SMR_VDCAON_Msk                    (0x01UL << SCU_SMR_VDCAON_Pos)                          /*!< SCU SMR: VDCAON Mask                    */

/* ----------------------------------  SCU_SRCR  ---------------------------------- */
#define SCU_SRCR_SWRST_Pos                    0                                                       /*!< SCU SRCR: SWRST Position                */
#define SCU_SRCR_SWRST_Msk                    (0x01UL << SCU_SRCR_SWRST_Pos)                          /*!< SCU SRCR: SWRST Mask                    */
#define SCU_SRCR_STBYOP_Pos                   4                                                       /*!< SCU SRCR: STBYOP Position               */
#define SCU_SRCR_STBYOP_Msk                   (0x01UL << SCU_SRCR_STBYOP_Pos)                         /*!< SCU SRCR: STBYOP Mask                   */

/* ----------------------------------  SCU_WUER  ---------------------------------- */
#define SCU_WUER_LVDWUE_Pos                   0                                                       /*!< SCU WUER: LVDWUE Position               */
#define SCU_WUER_LVDWUE_Msk                   (0x01UL << SCU_WUER_LVDWUE_Pos)                         /*!< SCU WUER: LVDWUE Mask                   */
#define SCU_WUER_WDTWUE_Pos                   1                                                       /*!< SCU WUER: WDTWUE Position               */
#define SCU_WUER_WDTWUE_Msk                   (0x01UL << SCU_WUER_WDTWUE_Pos)                         /*!< SCU WUER: WDTWUE Mask                   */
#define SCU_WUER_GPIOAWUE_Pos                 8                                                       /*!< SCU WUER: GPIOAWUE Position             */
#define SCU_WUER_GPIOAWUE_Msk                 (0x01UL << SCU_WUER_GPIOAWUE_Pos)                       /*!< SCU WUER: GPIOAWUE Mask                 */
#define SCU_WUER_GPIOBWUE_Pos                 9                                                       /*!< SCU WUER: GPIOBWUE Position             */
#define SCU_WUER_GPIOBWUE_Msk                 (0x01UL << SCU_WUER_GPIOBWUE_Pos)                       /*!< SCU WUER: GPIOBWUE Mask                 */
#define SCU_WUER_GPIOCWUE_Pos                 10                                                      /*!< SCU WUER: GPIOCWUE Position             */
#define SCU_WUER_GPIOCWUE_Msk                 (0x01UL << SCU_WUER_GPIOCWUE_Pos)                       /*!< SCU WUER: GPIOCWUE Mask                 */
#define SCU_WUER_GPIODWUE_Pos                 11                                                      /*!< SCU WUER: GPIODWUE Position             */
#define SCU_WUER_GPIODWUE_Msk                 (0x01UL << SCU_WUER_GPIODWUE_Pos)                       /*!< SCU WUER: GPIODWUE Mask                 */

/* ----------------------------------  SCU_WUSR  ---------------------------------- */
#define SCU_WUSR_LVDWU_Pos                    0                                                       /*!< SCU WUSR: LVDWU Position                */
#define SCU_WUSR_LVDWU_Msk                    (0x01UL << SCU_WUSR_LVDWU_Pos)                          /*!< SCU WUSR: LVDWU Mask                    */
#define SCU_WUSR_WDTWU_Pos                    1                                                       /*!< SCU WUSR: WDTWU Position                */
#define SCU_WUSR_WDTWU_Msk                    (0x01UL << SCU_WUSR_WDTWU_Pos)                          /*!< SCU WUSR: WDTWU Mask                    */
#define SCU_WUSR_GPIOAWU_Pos                  8                                                       /*!< SCU WUSR: GPIOAWU Position              */
#define SCU_WUSR_GPIOAWU_Msk                  (0x01UL << SCU_WUSR_GPIOAWU_Pos)                        /*!< SCU WUSR: GPIOAWU Mask                  */
#define SCU_WUSR_GPIOBWU_Pos                  9                                                       /*!< SCU WUSR: GPIOBWU Position              */
#define SCU_WUSR_GPIOBWU_Msk                  (0x01UL << SCU_WUSR_GPIOBWU_Pos)                        /*!< SCU WUSR: GPIOBWU Mask                  */
#define SCU_WUSR_GPIOCWU_Pos                  10                                                      /*!< SCU WUSR: GPIOCWU Position              */
#define SCU_WUSR_GPIOCWU_Msk                  (0x01UL << SCU_WUSR_GPIOCWU_Pos)                        /*!< SCU WUSR: GPIOCWU Mask                  */
#define SCU_WUSR_GPIODWU_Pos                  11                                                      /*!< SCU WUSR: GPIODWU Position              */
#define SCU_WUSR_GPIODWU_Msk                  (0x01UL << SCU_WUSR_GPIODWU_Pos)                        /*!< SCU WUSR: GPIODWU Mask                  */

/* ----------------------------------  SCU_RSER  ---------------------------------- */
#define SCU_RSER_LVDRST_Pos                   0                                                       /*!< SCU RSER: LVDRST Position               */
#define SCU_RSER_LVDRST_Msk                   (0x01UL << SCU_RSER_LVDRST_Pos)                         /*!< SCU RSER: LVDRST Mask                   */
#define SCU_RSER_XFRST_Pos                    1                                                       /*!< SCU RSER: XFRST Position                */
#define SCU_RSER_XFRST_Msk                    (0x01UL << SCU_RSER_XFRST_Pos)                          /*!< SCU RSER: XFRST Mask                    */
#define SCU_RSER_MCKFRST_Pos                  2                                                       /*!< SCU RSER: MCKFRST Position              */
#define SCU_RSER_MCKFRST_Msk                  (0x01UL << SCU_RSER_MCKFRST_Pos)                        /*!< SCU RSER: MCKFRST Mask                  */
#define SCU_RSER_WDTRST_Pos                   3                                                       /*!< SCU RSER: WDTRST Position               */
#define SCU_RSER_WDTRST_Msk                   (0x01UL << SCU_RSER_WDTRST_Pos)                         /*!< SCU RSER: WDTRST Mask                   */
#define SCU_RSER_SWRST_Pos                    4                                                       /*!< SCU RSER: SWRST Position                */
#define SCU_RSER_SWRST_Msk                    (0x01UL << SCU_RSER_SWRST_Pos)                          /*!< SCU RSER: SWRST Mask                    */
#define SCU_RSER_CPURST_Pos                   5                                                       /*!< SCU RSER: CPURST Position               */
#define SCU_RSER_CPURST_Msk                   (0x01UL << SCU_RSER_CPURST_Pos)                         /*!< SCU RSER: CPURST Mask                   */
#define SCU_RSER_PINRST_Pos                   6                                                       /*!< SCU RSER: PINRST Position               */
#define SCU_RSER_PINRST_Msk                   (0x01UL << SCU_RSER_PINRST_Pos)                         /*!< SCU RSER: PINRST Mask                   */

/* ----------------------------------  SCU_RSSR  ---------------------------------- */
#define SCU_RSSR_LVDRST_Pos                   0                                                       /*!< SCU RSSR: LVDRST Position               */
#define SCU_RSSR_LVDRST_Msk                   (0x01UL << SCU_RSSR_LVDRST_Pos)                         /*!< SCU RSSR: LVDRST Mask                   */
#define SCU_RSSR_XFRST_Pos                    1                                                       /*!< SCU RSSR: XFRST Position                */
#define SCU_RSSR_XFRST_Msk                    (0x01UL << SCU_RSSR_XFRST_Pos)                          /*!< SCU RSSR: XFRST Mask                    */
#define SCU_RSSR_MCKFRST_Pos                  2                                                       /*!< SCU RSSR: MCKFRST Position              */
#define SCU_RSSR_MCKFRST_Msk                  (0x01UL << SCU_RSSR_MCKFRST_Pos)                        /*!< SCU RSSR: MCKFRST Mask                  */
#define SCU_RSSR_WDTRST_Pos                   3                                                       /*!< SCU RSSR: WDTRST Position               */
#define SCU_RSSR_WDTRST_Msk                   (0x01UL << SCU_RSSR_WDTRST_Pos)                         /*!< SCU RSSR: WDTRST Mask                   */
#define SCU_RSSR_SWRST_Pos                    4                                                       /*!< SCU RSSR: SWRST Position                */
#define SCU_RSSR_SWRST_Msk                    (0x01UL << SCU_RSSR_SWRST_Pos)                          /*!< SCU RSSR: SWRST Mask                    */
#define SCU_RSSR_CPURST_Pos                   5                                                       /*!< SCU RSSR: CPURST Position               */
#define SCU_RSSR_CPURST_Msk                   (0x01UL << SCU_RSSR_CPURST_Pos)                         /*!< SCU RSSR: CPURST Mask                   */
#define SCU_RSSR_PINRST_Pos                   6                                                       /*!< SCU RSSR: PINRST Position               */
#define SCU_RSSR_PINRST_Msk                   (0x01UL << SCU_RSSR_PINRST_Pos)                         /*!< SCU RSSR: PINRST Mask                   */
#define SCU_RSSR_PORST_Pos                    7                                                       /*!< SCU RSSR: PORST Position                */
#define SCU_RSSR_PORST_Msk                    (0x01UL << SCU_RSSR_PORST_Pos)                          /*!< SCU RSSR: PORST Mask                    */

/* ----------------------------------  SCU_PRER1  --------------------------------- */
#define SCU_PRER1_SCU_Pos                     0                                                       /*!< SCU PRER1: SCU Position                 */
#define SCU_PRER1_SCU_Msk                     (0x01UL << SCU_PRER1_SCU_Pos)                           /*!< SCU PRER1: SCU Mask                     */
#define SCU_PRER1_FMC_Pos                     1                                                       /*!< SCU PRER1: FMC Position                 */
#define SCU_PRER1_FMC_Msk                     (0x01UL << SCU_PRER1_FMC_Pos)                           /*!< SCU PRER1: FMC Mask                     */
#define SCU_PRER1_WDT_Pos                     2                                                       /*!< SCU PRER1: WDT Position                 */
#define SCU_PRER1_WDT_Msk                     (0x01UL << SCU_PRER1_WDT_Pos)                           /*!< SCU PRER1: WDT Mask                     */
#define SCU_PRER1_PCU_Pos                     3                                                       /*!< SCU PRER1: PCU Position                 */
#define SCU_PRER1_PCU_Msk                     (0x01UL << SCU_PRER1_PCU_Pos)                           /*!< SCU PRER1: PCU Mask                     */
#define SCU_PRER1_DMA_Pos                     4                                                       /*!< SCU PRER1: DMA Position                 */
#define SCU_PRER1_DMA_Msk                     (0x01UL << SCU_PRER1_DMA_Pos)                           /*!< SCU PRER1: DMA Mask                     */
#define SCU_PRER1_GPIOA_Pos                   8                                                       /*!< SCU PRER1: GPIOA Position               */
#define SCU_PRER1_GPIOA_Msk                   (0x01UL << SCU_PRER1_GPIOA_Pos)                         /*!< SCU PRER1: GPIOA Mask                   */
#define SCU_PRER1_GPIOB_Pos                   9                                                       /*!< SCU PRER1: GPIOB Position               */
#define SCU_PRER1_GPIOB_Msk                   (0x01UL << SCU_PRER1_GPIOB_Pos)                         /*!< SCU PRER1: GPIOB Mask                   */
#define SCU_PRER1_GPIOC_Pos                   10                                                      /*!< SCU PRER1: GPIOC Position               */
#define SCU_PRER1_GPIOC_Msk                   (0x01UL << SCU_PRER1_GPIOC_Pos)                         /*!< SCU PRER1: GPIOC Mask                   */
#define SCU_PRER1_GPIOD_Pos                   11                                                      /*!< SCU PRER1: GPIOD Position               */
#define SCU_PRER1_GPIOD_Msk                   (0x01UL << SCU_PRER1_GPIOD_Pos)                         /*!< SCU PRER1: GPIOD Mask                   */
#define SCU_PRER1_TIMER0_Pos                  16                                                      /*!< SCU PRER1: TIMER0 Position              */
#define SCU_PRER1_TIMER0_Msk                  (0x01UL << SCU_PRER1_TIMER0_Pos)                        /*!< SCU PRER1: TIMER0 Mask                  */
#define SCU_PRER1_TIMER1_Pos                  17                                                      /*!< SCU PRER1: TIMER1 Position              */
#define SCU_PRER1_TIMER1_Msk                  (0x01UL << SCU_PRER1_TIMER1_Pos)                        /*!< SCU PRER1: TIMER1 Mask                  */
#define SCU_PRER1_TIMER2_Pos                  18                                                      /*!< SCU PRER1: TIMER2 Position              */
#define SCU_PRER1_TIMER2_Msk                  (0x01UL << SCU_PRER1_TIMER2_Pos)                        /*!< SCU PRER1: TIMER2 Mask                  */
#define SCU_PRER1_TIMER3_Pos                  19                                                      /*!< SCU PRER1: TIMER3 Position              */
#define SCU_PRER1_TIMER3_Msk                  (0x01UL << SCU_PRER1_TIMER3_Pos)                        /*!< SCU PRER1: TIMER3 Mask                  */
#define SCU_PRER1_TIMER8_Pos                  24                                                      /*!< SCU PRER1: TIMER8 Position              */
#define SCU_PRER1_TIMER8_Msk                  (0x01UL << SCU_PRER1_TIMER8_Pos)                        /*!< SCU PRER1: TIMER8 Mask                  */
#define SCU_PRER1_TIMER9_Pos                  25                                                      /*!< SCU PRER1: TIMER9 Position              */
#define SCU_PRER1_TIMER9_Msk                  (0x01UL << SCU_PRER1_TIMER9_Pos)                        /*!< SCU PRER1: TIMER9 Mask                  */

/* ----------------------------------  SCU_PRER2  --------------------------------- */
#define SCU_PRER2_SPI0_Pos                    0                                                       /*!< SCU PRER2: SPI0 Position                */
#define SCU_PRER2_SPI0_Msk                    (0x01UL << SCU_PRER2_SPI0_Pos)                          /*!< SCU PRER2: SPI0 Mask                    */
#define SCU_PRER2_IIC0_Pos                    4                                                       /*!< SCU PRER2: IIC0 Position                */
#define SCU_PRER2_IIC0_Msk                    (0x01UL << SCU_PRER2_IIC0_Pos)                          /*!< SCU PRER2: IIC0 Mask                    */
#define SCU_PRER2_UART0_Pos                   8                                                       /*!< SCU PRER2: UART0 Position               */
#define SCU_PRER2_UART0_Msk                   (0x01UL << SCU_PRER2_UART0_Pos)                         /*!< SCU PRER2: UART0 Mask                   */
#define SCU_PRER2_UART1_Pos                   9                                                       /*!< SCU PRER2: UART1 Position               */
#define SCU_PRER2_UART1_Msk                   (0x01UL << SCU_PRER2_UART1_Pos)                         /*!< SCU PRER2: UART1 Mask                   */
#define SCU_PRER2_MPWM0_Pos                   16                                                      /*!< SCU PRER2: MPWM0 Position               */
#define SCU_PRER2_MPWM0_Msk                   (0x01UL << SCU_PRER2_MPWM0_Pos)                         /*!< SCU PRER2: MPWM0 Mask                   */
#define SCU_PRER2_ADC0_Pos                    20                                                      /*!< SCU PRER2: ADC0 Position                */
#define SCU_PRER2_ADC0_Msk                    (0x01UL << SCU_PRER2_ADC0_Pos)                          /*!< SCU PRER2: ADC0 Mask                    */
#define SCU_PRER2_ADC1_Pos                    21                                                      /*!< SCU PRER2: ADC1 Position                */
#define SCU_PRER2_ADC1_Msk                    (0x01UL << SCU_PRER2_ADC1_Pos)                          /*!< SCU PRER2: ADC1 Mask                    */

/* ----------------------------------  SCU_PER1  ---------------------------------- */
#define SCU_PER1_DMA_Pos                      4                                                       /*!< SCU PER1: DMA Position                  */
#define SCU_PER1_DMA_Msk                      (0x01UL << SCU_PER1_DMA_Pos)                            /*!< SCU PER1: DMA Mask                      */
#define SCU_PER1_GPIOA_Pos                    8                                                       /*!< SCU PER1: GPIOA Position                */
#define SCU_PER1_GPIOA_Msk                    (0x01UL << SCU_PER1_GPIOA_Pos)                          /*!< SCU PER1: GPIOA Mask                    */
#define SCU_PER1_GPIOB_Pos                    9                                                       /*!< SCU PER1: GPIOB Position                */
#define SCU_PER1_GPIOB_Msk                    (0x01UL << SCU_PER1_GPIOB_Pos)                          /*!< SCU PER1: GPIOB Mask                    */
#define SCU_PER1_GPIOC_Pos                    10                                                      /*!< SCU PER1: GPIOC Position                */
#define SCU_PER1_GPIOC_Msk                    (0x01UL << SCU_PER1_GPIOC_Pos)                          /*!< SCU PER1: GPIOC Mask                    */
#define SCU_PER1_GPIOD_Pos                    11                                                      /*!< SCU PER1: GPIOD Position                */
#define SCU_PER1_GPIOD_Msk                    (0x01UL << SCU_PER1_GPIOD_Pos)                          /*!< SCU PER1: GPIOD Mask                    */
#define SCU_PER1_TIMER0_Pos                   16                                                      /*!< SCU PER1: TIMER0 Position               */
#define SCU_PER1_TIMER0_Msk                   (0x01UL << SCU_PER1_TIMER0_Pos)                         /*!< SCU PER1: TIMER0 Mask                   */
#define SCU_PER1_TIMER1_Pos                   17                                                      /*!< SCU PER1: TIMER1 Position               */
#define SCU_PER1_TIMER1_Msk                   (0x01UL << SCU_PER1_TIMER1_Pos)                         /*!< SCU PER1: TIMER1 Mask                   */
#define SCU_PER1_TIMER2_Pos                   18                                                      /*!< SCU PER1: TIMER2 Position               */
#define SCU_PER1_TIMER2_Msk                   (0x01UL << SCU_PER1_TIMER2_Pos)                         /*!< SCU PER1: TIMER2 Mask                   */
#define SCU_PER1_TIMER3_Pos                   19                                                      /*!< SCU PER1: TIMER3 Position               */
#define SCU_PER1_TIMER3_Msk                   (0x01UL << SCU_PER1_TIMER3_Pos)                         /*!< SCU PER1: TIMER3 Mask                   */
#define SCU_PER1_TIMER8_Pos                   24                                                      /*!< SCU PER1: TIMER8 Position               */
#define SCU_PER1_TIMER8_Msk                   (0x01UL << SCU_PER1_TIMER8_Pos)                         /*!< SCU PER1: TIMER8 Mask                   */
#define SCU_PER1_TIMER9_Pos                   25                                                      /*!< SCU PER1: TIMER9 Position               */
#define SCU_PER1_TIMER9_Msk                   (0x01UL << SCU_PER1_TIMER9_Pos)                         /*!< SCU PER1: TIMER9 Mask                   */

/* ----------------------------------  SCU_PER2  ---------------------------------- */
#define SCU_PER2_SPI0_Pos                     0                                                       /*!< SCU PER2: SPI0 Position                 */
#define SCU_PER2_SPI0_Msk                     (0x01UL << SCU_PER2_SPI0_Pos)                           /*!< SCU PER2: SPI0 Mask                     */
#define SCU_PER2_IIC0_Pos                     4                                                       /*!< SCU PER2: IIC0 Position                 */
#define SCU_PER2_IIC0_Msk                     (0x01UL << SCU_PER2_IIC0_Pos)                           /*!< SCU PER2: IIC0 Mask                     */
#define SCU_PER2_UART0_Pos                    8                                                       /*!< SCU PER2: UART0 Position                */
#define SCU_PER2_UART0_Msk                    (0x01UL << SCU_PER2_UART0_Pos)                          /*!< SCU PER2: UART0 Mask                    */
#define SCU_PER2_UART1_Pos                    9                                                       /*!< SCU PER2: UART1 Position                */
#define SCU_PER2_UART1_Msk                    (0x01UL << SCU_PER2_UART1_Pos)                          /*!< SCU PER2: UART1 Mask                    */
#define SCU_PER2_MPWM0_Pos                    16                                                      /*!< SCU PER2: MPWM0 Position                */
#define SCU_PER2_MPWM0_Msk                    (0x01UL << SCU_PER2_MPWM0_Pos)                          /*!< SCU PER2: MPWM0 Mask                    */
#define SCU_PER2_ADC0_Pos                     20                                                      /*!< SCU PER2: ADC0 Position                 */
#define SCU_PER2_ADC0_Msk                     (0x01UL << SCU_PER2_ADC0_Pos)                           /*!< SCU PER2: ADC0 Mask                     */
#define SCU_PER2_ADC1_Pos                     21                                                      /*!< SCU PER2: ADC1 Position                 */
#define SCU_PER2_ADC1_Msk                     (0x01UL << SCU_PER2_ADC1_Pos)                           /*!< SCU PER2: ADC1 Mask                     */

/* ----------------------------------  SCU_PCER1  --------------------------------- */
#define SCU_PCER1_DMA_Pos                     4                                                       /*!< SCU PCER1: DMA Position                 */
#define SCU_PCER1_DMA_Msk                     (0x01UL << SCU_PCER1_DMA_Pos)                           /*!< SCU PCER1: DMA Mask                     */
#define SCU_PCER1_GPIOA_Pos                   8                                                       /*!< SCU PCER1: GPIOA Position               */
#define SCU_PCER1_GPIOA_Msk                   (0x01UL << SCU_PCER1_GPIOA_Pos)                         /*!< SCU PCER1: GPIOA Mask                   */
#define SCU_PCER1_GPIOB_Pos                   9                                                       /*!< SCU PCER1: GPIOB Position               */
#define SCU_PCER1_GPIOB_Msk                   (0x01UL << SCU_PCER1_GPIOB_Pos)                         /*!< SCU PCER1: GPIOB Mask                   */
#define SCU_PCER1_GPIOC_Pos                   10                                                      /*!< SCU PCER1: GPIOC Position               */
#define SCU_PCER1_GPIOC_Msk                   (0x01UL << SCU_PCER1_GPIOC_Pos)                         /*!< SCU PCER1: GPIOC Mask                   */
#define SCU_PCER1_GPIOD_Pos                   11                                                      /*!< SCU PCER1: GPIOD Position               */
#define SCU_PCER1_GPIOD_Msk                   (0x01UL << SCU_PCER1_GPIOD_Pos)                         /*!< SCU PCER1: GPIOD Mask                   */
#define SCU_PCER1_TIMER0_Pos                  16                                                      /*!< SCU PCER1: TIMER0 Position              */
#define SCU_PCER1_TIMER0_Msk                  (0x01UL << SCU_PCER1_TIMER0_Pos)                        /*!< SCU PCER1: TIMER0 Mask                  */
#define SCU_PCER1_TIMER1_Pos                  17                                                      /*!< SCU PCER1: TIMER1 Position              */
#define SCU_PCER1_TIMER1_Msk                  (0x01UL << SCU_PCER1_TIMER1_Pos)                        /*!< SCU PCER1: TIMER1 Mask                  */
#define SCU_PCER1_TIMER2_Pos                  18                                                      /*!< SCU PCER1: TIMER2 Position              */
#define SCU_PCER1_TIMER2_Msk                  (0x01UL << SCU_PCER1_TIMER2_Pos)                        /*!< SCU PCER1: TIMER2 Mask                  */
#define SCU_PCER1_TIMER3_Pos                  19                                                      /*!< SCU PCER1: TIMER3 Position              */
#define SCU_PCER1_TIMER3_Msk                  (0x01UL << SCU_PCER1_TIMER3_Pos)                        /*!< SCU PCER1: TIMER3 Mask                  */
#define SCU_PCER1_TIMER8_Pos                  24                                                      /*!< SCU PCER1: TIMER8 Position              */
#define SCU_PCER1_TIMER8_Msk                  (0x01UL << SCU_PCER1_TIMER8_Pos)                        /*!< SCU PCER1: TIMER8 Mask                  */
#define SCU_PCER1_TIMER9_Pos                  25                                                      /*!< SCU PCER1: TIMER9 Position              */
#define SCU_PCER1_TIMER9_Msk                  (0x01UL << SCU_PCER1_TIMER9_Pos)                        /*!< SCU PCER1: TIMER9 Mask                  */

/* ----------------------------------  SCU_PCER2  --------------------------------- */
#define SCU_PCER2_SPI0_Pos                    0                                                       /*!< SCU PCER2: SPI0 Position                */
#define SCU_PCER2_SPI0_Msk                    (0x01UL << SCU_PCER2_SPI0_Pos)                          /*!< SCU PCER2: SPI0 Mask                    */
#define SCU_PCER2_IIC0_Pos                    4                                                       /*!< SCU PCER2: IIC0 Position                */
#define SCU_PCER2_IIC0_Msk                    (0x01UL << SCU_PCER2_IIC0_Pos)                          /*!< SCU PCER2: IIC0 Mask                    */
#define SCU_PCER2_UART0_Pos                   8                                                       /*!< SCU PCER2: UART0 Position               */
#define SCU_PCER2_UART0_Msk                   (0x01UL << SCU_PCER2_UART0_Pos)                         /*!< SCU PCER2: UART0 Mask                   */
#define SCU_PCER2_UART1_Pos                   9                                                       /*!< SCU PCER2: UART1 Position               */
#define SCU_PCER2_UART1_Msk                   (0x01UL << SCU_PCER2_UART1_Pos)                         /*!< SCU PCER2: UART1 Mask                   */
#define SCU_PCER2_MPWM0_Pos                   16                                                      /*!< SCU PCER2: MPWM0 Position               */
#define SCU_PCER2_MPWM0_Msk                   (0x01UL << SCU_PCER2_MPWM0_Pos)                         /*!< SCU PCER2: MPWM0 Mask                   */
#define SCU_PCER2_ADC0_Pos                    20                                                      /*!< SCU PCER2: ADC0 Position                */
#define SCU_PCER2_ADC0_Msk                    (0x01UL << SCU_PCER2_ADC0_Pos)                          /*!< SCU PCER2: ADC0 Mask                    */
#define SCU_PCER2_ADC1_Pos                    21                                                      /*!< SCU PCER2: ADC1 Position                */
#define SCU_PCER2_ADC1_Msk                    (0x01UL << SCU_PCER2_ADC1_Pos)                          /*!< SCU PCER2: ADC1 Mask                    */

/* ----------------------------------  SCU_CSCR  ---------------------------------- */
#define SCU_CSCR_EOSCON_Pos                   0                                                       /*!< SCU CSCR: EOSCON Position               */
#define SCU_CSCR_EOSCON_Msk                   (0x03UL << SCU_CSCR_EOSCON_Pos)                         /*!< SCU CSCR: EOSCON Mask                   */
#define SCU_CSCR_RINGOSCCON_Pos               4                                                       /*!< SCU CSCR: RINGOSCCON Position           */
#define SCU_CSCR_RINGOSCCON_Msk               (0x03UL << SCU_CSCR_RINGOSCCON_Pos)                     /*!< SCU CSCR: RINGOSCCON Mask               */

/* ----------------------------------  SCU_SCCR  ---------------------------------- */
#define SCU_SCCR_MCLKSEL_Pos                  0                                                       /*!< SCU SCCR: MCLKSEL Position              */
#define SCU_SCCR_MCLKSEL_Msk                  (0x03UL << SCU_SCCR_MCLKSEL_Pos)                        /*!< SCU SCCR: MCLKSEL Mask                  */
#define SCU_SCCR_FINSEL_Pos                   2                                                       /*!< SCU SCCR: FINSEL Position               */
#define SCU_SCCR_FINSEL_Msk                   (0x01UL << SCU_SCCR_FINSEL_Pos)                         /*!< SCU SCCR: FINSEL Mask                   */

/* -----------------------------------  SCU_CMR  ---------------------------------- */
#define SCU_CMR_EOSCSTS_Pos                   0                                                       /*!< SCU CMR: EOSCSTS Position               */
#define SCU_CMR_EOSCSTS_Msk                   (0x01UL << SCU_CMR_EOSCSTS_Pos)                         /*!< SCU CMR: EOSCSTS Mask                   */
#define SCU_CMR_EOSCFAIL_Pos                  1                                                       /*!< SCU CMR: EOSCFAIL Position              */
#define SCU_CMR_EOSCFAIL_Msk                  (0x01UL << SCU_CMR_EOSCFAIL_Pos)                        /*!< SCU CMR: EOSCFAIL Mask                  */
#define SCU_CMR_EOSCIE_Pos                    2                                                       /*!< SCU CMR: EOSCIE Position                */
#define SCU_CMR_EOSCIE_Msk                    (0x01UL << SCU_CMR_EOSCIE_Pos)                          /*!< SCU CMR: EOSCIE Mask                    */
#define SCU_CMR_EOSCMNT_Pos                   3                                                       /*!< SCU CMR: EOSCMNT Position               */
#define SCU_CMR_EOSCMNT_Msk                   (0x01UL << SCU_CMR_EOSCMNT_Pos)                         /*!< SCU CMR: EOSCMNT Mask                   */
#define SCU_CMR_MCLKSTS_Pos                   4                                                       /*!< SCU CMR: MCLKSTS Position               */
#define SCU_CMR_MCLKSTS_Msk                   (0x01UL << SCU_CMR_MCLKSTS_Pos)                         /*!< SCU CMR: MCLKSTS Mask                   */
#define SCU_CMR_MCLKFAIL_Pos                  5                                                       /*!< SCU CMR: MCLKFAIL Position              */
#define SCU_CMR_MCLKFAIL_Msk                  (0x01UL << SCU_CMR_MCLKFAIL_Pos)                        /*!< SCU CMR: MCLKFAIL Mask                  */
#define SCU_CMR_MCLKIE_Pos                    6                                                       /*!< SCU CMR: MCLKIE Position                */
#define SCU_CMR_MCLKIE_Msk                    (0x01UL << SCU_CMR_MCLKIE_Pos)                          /*!< SCU CMR: MCLKIE Mask                    */
#define SCU_CMR_MCLKMNT_Pos                   7                                                       /*!< SCU CMR: MCLKMNT Position               */
#define SCU_CMR_MCLKMNT_Msk                   (0x01UL << SCU_CMR_MCLKMNT_Pos)                         /*!< SCU CMR: MCLKMNT Mask                   */
#define SCU_CMR_MCLKREC_Pos                   15                                                      /*!< SCU CMR: MCLKREC Position               */
#define SCU_CMR_MCLKREC_Msk                   (0x01UL << SCU_CMR_MCLKREC_Pos)                         /*!< SCU CMR: MCLKREC Mask                   */

/* ----------------------------------  SCU_NMIR  ---------------------------------- */
#define SCU_NMIR_LVDEN_Pos                    0                                                       /*!< SCU NMIR: LVDEN Position                */
#define SCU_NMIR_LVDEN_Msk                    (0x01UL << SCU_NMIR_LVDEN_Pos)                          /*!< SCU NMIR: LVDEN Mask                    */
#define SCU_NMIR_MCLKFAILEN_Pos               1                                                       /*!< SCU NMIR: MCLKFAILEN Position           */
#define SCU_NMIR_MCLKFAILEN_Msk               (0x01UL << SCU_NMIR_MCLKFAILEN_Pos)                     /*!< SCU NMIR: MCLKFAILEN Mask               */
#define SCU_NMIR_WDTINTEN_Pos                 2                                                       /*!< SCU NMIR: WDTINTEN Position             */
#define SCU_NMIR_WDTINTEN_Msk                 (0x01UL << SCU_NMIR_WDTINTEN_Pos)                       /*!< SCU NMIR: WDTINTEN Mask                 */
#define SCU_NMIR_OVPEN_Pos                    3                                                       /*!< SCU NMIR: OVPEN Position                */
#define SCU_NMIR_OVPEN_Msk                    (0x01UL << SCU_NMIR_OVPEN_Pos)                          /*!< SCU NMIR: OVPEN Mask                    */
#define SCU_NMIR_PROTEN_Pos                   4                                                       /*!< SCU NMIR: PROTEN Position               */
#define SCU_NMIR_PROTEN_Msk                   (0x01UL << SCU_NMIR_PROTEN_Pos)                         /*!< SCU NMIR: PROTEN Mask                   */
#define SCU_NMIR_LVDSTS_Pos                   8                                                       /*!< SCU NMIR: LVDSTS Position               */
#define SCU_NMIR_LVDSTS_Msk                   (0x01UL << SCU_NMIR_LVDSTS_Pos)                         /*!< SCU NMIR: LVDSTS Mask                   */
#define SCU_NMIR_MCLKFAILSTS_Pos              9                                                       /*!< SCU NMIR: MCLKFAILSTS Position          */
#define SCU_NMIR_MCLKFAILSTS_Msk              (0x01UL << SCU_NMIR_MCLKFAILSTS_Pos)                    /*!< SCU NMIR: MCLKFAILSTS Mask              */
#define SCU_NMIR_WDTINTSTS_Pos                10                                                      /*!< SCU NMIR: WDTINTSTS Position            */
#define SCU_NMIR_WDTINTSTS_Msk                (0x01UL << SCU_NMIR_WDTINTSTS_Pos)                      /*!< SCU NMIR: WDTINTSTS Mask                */
#define SCU_NMIR_OVPSTS_Pos                   11                                                      /*!< SCU NMIR: OVPSTS Position               */
#define SCU_NMIR_OVPSTS_Msk                   (0x01UL << SCU_NMIR_OVPSTS_Pos)                         /*!< SCU NMIR: OVPSTS Mask                   */
#define SCU_NMIR_PROTSTS_Pos                  12                                                      /*!< SCU NMIR: PROTSTS Position              */
#define SCU_NMIR_PROTSTS_Msk                  (0x01UL << SCU_NMIR_PROTSTS_Pos)                        /*!< SCU NMIR: PROTSTS Mask                  */

/* -----------------------------------  SCU_COR  ---------------------------------- */
#define SCU_COR_CLOKODIV_Pos                  0                                                       /*!< SCU COR: CLOKODIV Position              */
#define SCU_COR_CLOKODIV_Msk                  (0x0fUL << SCU_COR_CLOKODIV_Pos)                        /*!< SCU COR: CLOKODIV Mask                  */
#define SCU_COR_CLKOEN_Pos                    4                                                       /*!< SCU COR: CLKOEN Position                */
#define SCU_COR_CLKOEN_Msk                    (0x01UL << SCU_COR_CLKOEN_Pos)                          /*!< SCU COR: CLKOEN Mask                    */

/* ---------------------------------  SCU_PLLCON  --------------------------------- */
#define SCU_PLLCON_POSTDIV_Pos                0                                                       /*!< SCU PLLCON: POSTDIV Position            */
#define SCU_PLLCON_POSTDIV_Msk                (0x0fUL << SCU_PLLCON_POSTDIV_Pos)                      /*!< SCU PLLCON: POSTDIV Mask                */
#define SCU_PLLCON_FBCTRL_Pos                 4                                                       /*!< SCU PLLCON: FBCTRL Position             */
#define SCU_PLLCON_FBCTRL_Msk                 (0x0fUL << SCU_PLLCON_FBCTRL_Pos)                       /*!< SCU PLLCON: FBCTRL Mask                 */
#define SCU_PLLCON_PREDIV_Pos                 8                                                       /*!< SCU PLLCON: PREDIV Position             */
#define SCU_PLLCON_PREDIV_Msk                 (0x01UL << SCU_PLLCON_PREDIV_Pos)                       /*!< SCU PLLCON: PREDIV Mask                 */
#define SCU_PLLCON_LOCK_Pos                   12                                                      /*!< SCU PLLCON: LOCK Position               */
#define SCU_PLLCON_LOCK_Msk                   (0x01UL << SCU_PLLCON_LOCK_Pos)                         /*!< SCU PLLCON: LOCK Mask                   */
#define SCU_PLLCON_BYPASS_Pos                 13                                                      /*!< SCU PLLCON: BYPASS Position             */
#define SCU_PLLCON_BYPASS_Msk                 (0x01UL << SCU_PLLCON_BYPASS_Pos)                       /*!< SCU PLLCON: BYPASS Mask                 */
#define SCU_PLLCON_PLL_EN_Pos                 14                                                      /*!< SCU PLLCON: PLL_EN Position             */
#define SCU_PLLCON_PLL_EN_Msk                 (0x01UL << SCU_PLLCON_PLL_EN_Pos)                       /*!< SCU PLLCON: PLL_EN Mask                 */
#define SCU_PLLCON_PLLRSTB_Pos                15                                                      /*!< SCU PLLCON: PLLRSTB Position            */
#define SCU_PLLCON_PLLRSTB_Msk                (0x01UL << SCU_PLLCON_PLLRSTB_Pos)                      /*!< SCU PLLCON: PLLRSTB Mask                */

/* ---------------------------------  SCU_VDCCON  --------------------------------- */
#define SCU_VDCCON_VDCWDLY_Pos                0                                                       /*!< SCU VDCCON: VDCWDLY Position            */
#define SCU_VDCCON_VDCWDLY_Msk                (0x000000ffUL << SCU_VDCCON_VDCWDLY_Pos)                /*!< SCU VDCCON: VDCWDLY Mask                */
#define SCU_VDCCON_VDCDE_Pos                  8                                                       /*!< SCU VDCCON: VDCDE Position              */
#define SCU_VDCCON_VDCDE_Msk                  (0x01UL << SCU_VDCCON_VDCDE_Pos)                        /*!< SCU VDCCON: VDCDE Mask                  */
#define SCU_VDCCON_VDCTRIM_Pos                16                                                      /*!< SCU VDCCON: VDCTRIM Position            */
#define SCU_VDCCON_VDCTRIM_Msk                (0x0fUL << SCU_VDCCON_VDCTRIM_Pos)                      /*!< SCU VDCCON: VDCTRIM Mask                */
#define SCU_VDCCON_VDCTE_Pos                  23                                                      /*!< SCU VDCCON: VDCTE Position              */
#define SCU_VDCCON_VDCTE_Msk                  (0x01UL << SCU_VDCCON_VDCTE_Pos)                        /*!< SCU VDCCON: VDCTE Mask                  */
#define SCU_VDCCON_BMRTE_Pos                  31                                                      /*!< SCU VDCCON: BMRTE Position              */
#define SCU_VDCCON_BMRTE_Msk                  (0x01UL << SCU_VDCCON_BMRTE_Pos)                        /*!< SCU VDCCON: BMRTE Mask                  */

/* ---------------------------------  SCU_LVDCON  --------------------------------- */
#define SCU_LVDCON_LVDEN_Pos                  0                                                       /*!< SCU LVDCON: LVDEN Position              */
#define SCU_LVDCON_LVDEN_Msk                  (0x01UL << SCU_LVDCON_LVDEN_Pos)                        /*!< SCU LVDCON: LVDEN Mask                  */
#define SCU_LVDCON_LVDLVL_Pos                 1                                                       /*!< SCU LVDCON: LVDLVL Position             */
#define SCU_LVDCON_LVDLVL_Msk                 (0x01UL << SCU_LVDCON_LVDLVL_Pos)                       /*!< SCU LVDCON: LVDLVL Mask                 */
#define SCU_LVDCON_LVDSEL_Pos                 8                                                       /*!< SCU LVDCON: LVDSEL Position             */
#define SCU_LVDCON_LVDSEL_Msk                 (0x03UL << SCU_LVDCON_LVDSEL_Pos)                       /*!< SCU LVDCON: LVDSEL Mask                 */
#define SCU_LVDCON_SELEN_Pos                  15                                                      /*!< SCU LVDCON: SELEN Position              */
#define SCU_LVDCON_SELEN_Msk                  (0x01UL << SCU_LVDCON_SELEN_Pos)                        /*!< SCU LVDCON: SELEN Mask                  */
#define SCU_LVDCON_LVDTRIM_Pos                16                                                      /*!< SCU LVDCON: LVDTRIM Position            */
#define SCU_LVDCON_LVDTRIM_Msk                (0x03UL << SCU_LVDCON_LVDTRIM_Pos)                      /*!< SCU LVDCON: LVDTRIM Mask                */
#define SCU_LVDCON_LVDTE_Pos                  23                                                      /*!< SCU LVDCON: LVDTE Position              */
#define SCU_LVDCON_LVDTE_Msk                  (0x01UL << SCU_LVDCON_LVDTE_Pos)                        /*!< SCU LVDCON: LVDTE Mask                  */

/* ----------------------------------  SCU_EOSCR  --------------------------------- */
#define SCU_EOSCR_ISEL_Pos                    8                                                       /*!< SCU EOSCR: ISEL Position                */
#define SCU_EOSCR_ISEL_Msk                    (0x03UL << SCU_EOSCR_ISEL_Pos)                          /*!< SCU EOSCR: ISEL Mask                    */
#define SCU_EOSCR_ISELEN_Pos                  15                                                      /*!< SCU EOSCR: ISELEN Position              */
#define SCU_EOSCR_ISELEN_Msk                  (0x01UL << SCU_EOSCR_ISELEN_Pos)                        /*!< SCU EOSCR: ISELEN Mask                  */

/* ----------------------------------  SCU_EMODR  --------------------------------- */
#define SCU_EMODR_BOOT_Pos                    0                                                       /*!< SCU EMODR: BOOT Position                */
#define SCU_EMODR_BOOT_Msk                    (0x01UL << SCU_EMODR_BOOT_Pos)                          /*!< SCU EMODR: BOOT Mask                    */
#define SCU_EMODR_TEST_Pos                    1                                                       /*!< SCU EMODR: TEST Position                */
#define SCU_EMODR_TEST_Msk                    (0x01UL << SCU_EMODR_TEST_Pos)                          /*!< SCU EMODR: TEST Mask                    */
#define SCU_EMODR_SCANMD_Pos                  2                                                       /*!< SCU EMODR: SCANMD Position              */
#define SCU_EMODR_SCANMD_Msk                  (0x01UL << SCU_EMODR_SCANMD_Pos)                        /*!< SCU EMODR: SCANMD Mask                  */

/* ----------------------------------  SCU_MCCR1  --------------------------------- */
#define SCU_MCCR1_STDIV_Pos                   0                                                       /*!< SCU MCCR1: STDIV Position               */
#define SCU_MCCR1_STDIV_Msk                   (0x000000ffUL << SCU_MCCR1_STDIV_Pos)                   /*!< SCU MCCR1: STDIV Mask                   */
#define SCU_MCCR1_STCSEL_Pos                  8                                                       /*!< SCU MCCR1: STCSEL Position              */
#define SCU_MCCR1_STCSEL_Msk                  (0x07UL << SCU_MCCR1_STCSEL_Pos)                        /*!< SCU MCCR1: STCSEL Mask                  */
#define SCU_MCCR1_TRACEDIV_Pos                16                                                      /*!< SCU MCCR1: TRACEDIV Position            */
#define SCU_MCCR1_TRACEDIV_Msk                (0x000000ffUL << SCU_MCCR1_TRACEDIV_Pos)                /*!< SCU MCCR1: TRACEDIV Mask                */
#define SCU_MCCR1_TRCSEL_Pos                  24                                                      /*!< SCU MCCR1: TRCSEL Position              */
#define SCU_MCCR1_TRCSEL_Msk                  (0x07UL << SCU_MCCR1_TRCSEL_Pos)                        /*!< SCU MCCR1: TRCSEL Mask                  */
#define SCU_MCCR1_TRCPOL_Pos                  31                                                      /*!< SCU MCCR1: TRCPOL Position              */
#define SCU_MCCR1_TRCPOL_Msk                  (0x01UL << SCU_MCCR1_TRCPOL_Pos)                        /*!< SCU MCCR1: TRCPOL Mask                  */

/* ----------------------------------  SCU_MCCR2  --------------------------------- */
#define SCU_MCCR2_PWM0DIV_Pos                 0                                                       /*!< SCU MCCR2: PWM0DIV Position             */
#define SCU_MCCR2_PWM0DIV_Msk                 (0x000000ffUL << SCU_MCCR2_PWM0DIV_Pos)                 /*!< SCU MCCR2: PWM0DIV Mask                 */
#define SCU_MCCR2_PWM0CSEL_Pos                8                                                       /*!< SCU MCCR2: PWM0CSEL Position            */
#define SCU_MCCR2_PWM0CSEL_Msk                (0x07UL << SCU_MCCR2_PWM0CSEL_Pos)                      /*!< SCU MCCR2: PWM0CSEL Mask                */

/* ----------------------------------  SCU_MCCR3  --------------------------------- */
#define SCU_MCCR3_WDTDIV_Pos                  0                                                       /*!< SCU MCCR3: WDTDIV Position              */
#define SCU_MCCR3_WDTDIV_Msk                  (0x000000ffUL << SCU_MCCR3_WDTDIV_Pos)                  /*!< SCU MCCR3: WDTDIV Mask                  */
#define SCU_MCCR3_WDTCSEL_Pos                 8                                                       /*!< SCU MCCR3: WDTCSEL Position             */
#define SCU_MCCR3_WDTCSEL_Msk                 (0x07UL << SCU_MCCR3_WDTCSEL_Pos)                       /*!< SCU MCCR3: WDTCSEL Mask                 */
#define SCU_MCCR3_TEXT0DIV_Pos                16                                                      /*!< SCU MCCR3: TEXT0DIV Position            */
#define SCU_MCCR3_TEXT0DIV_Msk                (0x000000ffUL << SCU_MCCR3_TEXT0DIV_Pos)                /*!< SCU MCCR3: TEXT0DIV Mask                */
#define SCU_MCCR3_TEXT0CSEL_Pos               24                                                      /*!< SCU MCCR3: TEXT0CSEL Position           */
#define SCU_MCCR3_TEXT0CSEL_Msk               (0x07UL << SCU_MCCR3_TEXT0CSEL_Pos)                     /*!< SCU MCCR3: TEXT0CSEL Mask               */

/* ----------------------------------  SCU_MCCR4  --------------------------------- */
#define SCU_MCCR4_PADDIV_Pos                  0                                                       /*!< SCU MCCR4: PADDIV Position              */
#define SCU_MCCR4_PADDIV_Msk                  (0x000000ffUL << SCU_MCCR4_PADDIV_Pos)                  /*!< SCU MCCR4: PADDIV Mask                  */
#define SCU_MCCR4_PADCSEL_Pos                 8                                                       /*!< SCU MCCR4: PADCSEL Position             */
#define SCU_MCCR4_PADCSEL_Msk                 (0x07UL << SCU_MCCR4_PADCSEL_Pos)                       /*!< SCU MCCR4: PADCSEL Mask                 */
#define SCU_MCCR4_PBDDIV_Pos                  16                                                      /*!< SCU MCCR4: PBDDIV Position              */
#define SCU_MCCR4_PBDDIV_Msk                  (0x000000ffUL << SCU_MCCR4_PBDDIV_Pos)                  /*!< SCU MCCR4: PBDDIV Mask                  */
#define SCU_MCCR4_PBDSEL_Pos                  24                                                      /*!< SCU MCCR4: PBDSEL Position              */
#define SCU_MCCR4_PBDSEL_Msk                  (0x07UL << SCU_MCCR4_PBDSEL_Pos)                        /*!< SCU MCCR4: PBDSEL Mask                  */

/* ----------------------------------  SCU_MCCR5  --------------------------------- */
#define SCU_MCCR5_PCDDIV_Pos                  0                                                       /*!< SCU MCCR5: PCDDIV Position              */
#define SCU_MCCR5_PCDDIV_Msk                  (0x000000ffUL << SCU_MCCR5_PCDDIV_Pos)                  /*!< SCU MCCR5: PCDDIV Mask                  */
#define SCU_MCCR5_PCDSEK_Pos                  8                                                       /*!< SCU MCCR5: PCDSEK Position              */
#define SCU_MCCR5_PCDSEK_Msk                  (0x07UL << SCU_MCCR5_PCDSEK_Pos)                        /*!< SCU MCCR5: PCDSEK Mask                  */
#define SCU_MCCR5_PDDDIV_Pos                  16                                                      /*!< SCU MCCR5: PDDDIV Position              */
#define SCU_MCCR5_PDDDIV_Msk                  (0x000000ffUL << SCU_MCCR5_PDDDIV_Pos)                  /*!< SCU MCCR5: PDDDIV Mask                  */
#define SCU_MCCR5_PDDCSEL_Pos                 24                                                      /*!< SCU MCCR5: PDDCSEL Position             */
#define SCU_MCCR5_PDDCSEL_Msk                 (0x07UL << SCU_MCCR5_PDDCSEL_Pos)                       /*!< SCU MCCR5: PDDCSEL Mask                 */

/* ----------------------------------  SCU_MCCR7  --------------------------------- */
#define SCU_MCCR7_ADCCDIV_Pos                 16                                                      /*!< SCU MCCR7: ADCCDIV Position             */
#define SCU_MCCR7_ADCCDIV_Msk                 (0x000000ffUL << SCU_MCCR7_ADCCDIV_Pos)                 /*!< SCU MCCR7: ADCCDIV Mask                 */
#define SCU_MCCR7_ADCCSEL_Pos                 24                                                      /*!< SCU MCCR7: ADCCSEL Position             */
#define SCU_MCCR7_ADCCSEL_Msk                 (0x07UL << SCU_MCCR7_ADCCSEL_Pos)                       /*!< SCU MCCR7: ADCCSEL Mask                 */




/* External crystal oscillator control */
#define EXOSC_STOP		 			0x0				
#define EXOSC_EN				 			0x2				
#define EXOSC_EN_DIV2 			0x3		

/* External crystal oscillator stable timeout */
#define MOSC_STARTUP_TIMEOUT 0xFFFFFFFFUL

	/* Internal ring oscillator control */
#define INRINGOSC_STOP		 			0x0				
#define INRINGOSC_EN				 			0x2				
#define INRINGOSC_EN_DIV2 		0x3		

/* system clock control setting */
#define SC_INRINGOSC	0x0
#define SC_EXOSC          0x6
#define SC_EXOSCPLL     0x7
 
/* PLL stable timeout */
#define PLL_STARTUP_TIMEOUT 0xFFFFFFFFUL

/* PLLCON[BYPASS] */
#define PLLCON_BYPASS_FIN 0
#define PLLCON_BYPASS_PLL 1

// PLL freq = (FIN or FIN/2) * M / N
/* PLLCON[PREDIV] */
#define PLLCON_FIN_DIV_1 0
#define PLLCON_FIN_DIV_2 1

/* PLLCON[FBCTRL] */
#define PLLCON_M_4 0
#define PLLCON_M_6 1
#define PLLCON_M_8 2
#define PLLCON_M_10 3
#define PLLCON_M_12 4
#define PLLCON_M_14 5
#define PLLCON_M_16 6
#define PLLCON_M_18 7
#define PLLCON_M_20 8
#define PLLCON_M_24 9
#define PLLCON_M_26 10
#define PLLCON_M_34 11

/* PLLCON[POSTDIV] */
#define PLLCON_N_1 0
#define PLLCON_N_2 1
#define PLLCON_N_3 2
#define PLLCON_N_4 3
#define PLLCON_N_6 4
#define PLLCON_N_8 5
#define PLLCON_N_16 7

enum {
	SYSTICK_TYPE=0,
	TRACE_TYPE,
	PWM0_TYPE,
	WDT_TYPE,
	TEXT_TYPE,
	PAD_TYPE,
	PBD_TYPE,
	PCD_TYPE,
	PDD_TYPE,	
	ADCC_TYPE		
};

enum {
	CLKSRC_RING_OSC_1M=0,
	CLKSRC_MCLK=4,
	CLKSRC_EOSC=6,	
	CLKSRC_PLL=7	
};

enum {
	LVD_LEVEL_1_8 = 0,
	LVD_LEVEL_2_2,
	LVD_LEVEL_2_7,
	LVD_LEVEL_4_3
};

#define WAKEUP_GPIOD     (1UL<<11)
#define WAKEUP_GPIOC     (1UL<<10)
#define WAKEUP_GPIOB     (1UL<<9)
#define WAKEUP_GPIOA     (1UL<<8)
#define WAKEUP_WDT        (1UL<<1)
#define WAKEUP_LVD        (1UL<<0)


/* Public Functions ----------------------------------------------------------- */


void HAL_SCU_HSE_ClockConfig(uint8_t eosccon);	 // exosc set
Status HAL_SCU_HSE_ClockMonitoring(void); // check for MOSC stable 

void HAL_SCU_LSI_ClockConfig(uint8_t ringosc); // in ring osc set 
void HAL_SCU_SystemClockChange(uint8_t sysclkcon); // set system clock ==> final MCLK
void HAL_SCU_ClockOutput(uint8_t divval, FunctionalState endis);

void HAL_SCU_MiscClockConfig(uint8_t mccrnum, uint8_t type, int8_t clksrc, int8_t clkdiv);

void HAL_SCU_WakeUpSRCCmd(uint32_t WakeUpSrc, FunctionalState NewState);
uint32_t HAL_SCU_GetWakeUpSRCStatus(void);
void HAL_SCU_ClearWakeUpSRC(uint32_t WakeUpStatus);

void HAL_SCU_LVRCmd(FunctionalState NewState);
	
Status HAL_SCU_PLL_ClockConfig(FunctionalState pllsetstate, uint8_t selbypass, uint8_t selfin, uint8_t MM, uint8_t NN);

uint32_t HAL_SCU_GetNMIStatus(void);
void HAL_SCU_SetNMI(uint32_t nmisrc);

	


#endif /* end _AC33MX064_SCU_H_ */

/* --------------------------------- End Of File ------------------------------ */
