/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void ADC_Configure(void);
void ADC_PollingRun(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
static uint16_t adcval[8];
static uint32_t i,adcavg, tmp;
static ADC_CFG_Type AD0_config;

static const uint8_t menu[] =
"************************************************\n\r"
" ADC demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" Using ADC0 in polling mode \n\r"
"************************************************\n\r";

/* Public Function ------------------------------------------------------------*/
/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}

/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}


/**********************************************************************
 * @brief		adcaverage
 * @param[in]	*val 	adc value
 * @return 		adc average value
 **********************************************************************/
uint16_t adcaverage(uint16_t *val)
{
	uint32_t i;
	uint32_t adcavg;
	
	adcavg=0;			
	for (i=4;i<8;i++){	
		adcavg+=(val[i]>>4);
	}
	adcavg>>=2;
	
	return 	(adcavg);
}


/**********************************************************************
 * @brief		ADC_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void ADC_Configure(void)
{
	AD0_config.Mode = ADC_SINGLE_MODE;
	AD0_config.SamplingTime=15;
	AD0_config.SeqCnt = 1;
	AD0_config.RestartEn = 0;
	AD0_config.TrgSel = ADC_TRIGGER_DISABLE;
	
	AD0_config.UseClk = ADC_INTERNAL_CLK;
	AD0_config.InClkDiv = (((SystemPeriClock/1000000UL) * 2)/ (3*(15+AD0_config.SamplingTime))) + 1; 
	
	HAL_ADC_Init(AD0, &AD0_config);
	HAL_ADC_Init(AD1, &AD0_config);
}


/**********************************************************************
 * @brief		ADC_PollingRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void ADC_PollingRun(void)
{			
	HAL_ADC_ChannelSel(AD0, 0); // select ch
		
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD0); // start 	
		while((HAL_ADC_GetStatus(AD0) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD0);
	}
		
	adcavg=adcaverage(adcval);
	_DBG("0AN0 = "); _DBH16(adcavg); _DBG(" ");


	HAL_ADC_ChannelSel(AD1, 1);	
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD1); // start 	
		while((HAL_ADC_GetStatus(AD1) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD1);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("1AN1 = "); _DBH16(adcavg); _DBG(" ");

	
	HAL_ADC_ChannelSel(AD0, 2);			
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD0); // start 	
		while((HAL_ADC_GetStatus(AD0) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD0);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("0AN2 = "); _DBH16(adcavg); _DBG(" ");

	HAL_ADC_ChannelSel(AD1, 3); // select ch
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD1); // start 	
		while((HAL_ADC_GetStatus(AD1) & (ADC_STAT_END)) !=(ADC_STAT_END)){}	
		adcval[i]=HAL_ADC_GetData(AD1);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("1AN3 = "); _DBH16(adcavg); _DBG_(" ");
	
	#if 0
	HAL_ADC_ChannelSel(AD0, 4);	
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD0); // start 	
		while((HAL_ADC_GetStatus(AD0) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD0);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("AN4 = "); _DBH16(adcavg); _DBG(" ");

	
	HAL_ADC_ChannelSel(AD0, 5);			
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD0); // start 	
		while((HAL_ADC_GetStatus(AD0) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD0);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("AN8 = "); _DBH16(adcavg); _DBG(" ");

	HAL_ADC_ChannelSel(AD0, 6);	
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD0); // start 	
		while((HAL_ADC_GetStatus(AD0) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD0);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("AN9 = "); _DBH16(adcavg); _DBG(" ");

	HAL_ADC_ChannelSel(AD0, 7);	
	for (i=0;i<(8);i++){
		HAL_ADC_Start(AD0); // start 	
		while((HAL_ADC_GetStatus(AD0) & (ADC_STAT_END)) !=(ADC_STAT_END)){}
		adcval[i]=HAL_ADC_GetData(AD0);
	}
	
	adcavg=adcaverage(adcval);
	_DBG("AN10 = "); _DBH16(adcavg); _DBG_(" ");
#endif
	
		for(tmp = 0; tmp < 1000000; tmp++);
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	ADC_Configure();
	
	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1)
	{
		/*ADC Polling Test start*/
		ADC_PollingRun();
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
