/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void GPIO_Configure(void);
void GPIO_ExtIntRun(void);
void delay(void);
void mainloop(void);
int main (void);
void Error_Handler(void);
void GPIOBE_IRQHandler_IT(void);
void GPIOBO_IRQHandler_IT(void);
/* Private variables ---------------------------------------------------------*/

const uint8_t menu[] =
"************************************************\n\r"
"GPIO External Interrupt demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" This example used to configure the\n\r "
" GPIO PB6,7 as source of external Interrupt \n\r"
"************************************************\n\r";

/* Public Function ------------------------------------------------------------*/
/*******************************************************************************
* @brief      GPIOB even interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void GPIOBE_IRQHandler_IT(void)
{
	uint32_t j;
	uint32_t status;
	
	status = HAL_GPIO_EXTI_GetStatus(PCB);
	if(status & (3<<(6<<1)))
	{
		HAL_GPIO_EXTI_ClearPin(PCB, status & (3<<(6<<1)));
		for (j= 0; j<5; j++)
		{
			HAL_GPIO_SetPin(PB, _BIT(0));
			delay();
			HAL_GPIO_ClearPin(PB, _BIT(0));
			delay();
		}
	}	
}

/*******************************************************************************
* @brief      GPIOB odd interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void GPIOBO_IRQHandler_IT(void)
{
	uint32_t j;
	uint32_t status;
	
	status = HAL_GPIO_EXTI_GetStatus(PCB);
	if(status & (3<<(7<<1)))
	{
		HAL_GPIO_EXTI_ClearPin(PCB, status & (3<<(7<<1)));
		for (j= 0; j<5; j++)
		{
			HAL_GPIO_SetPin(PB, _BIT(1));
			delay();
			HAL_GPIO_ClearPin(PB, _BIT(1));
			delay();
		}
	}		
}

/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}


/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}


/**********************************************************************
 * @brief		delay
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void delay(void)
{
	uint32_t i;
	
	for (i = 0; i < 0x100000; i++) ;	
}


/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	// Test Pin setting PB0
	HAL_GPIO_ConfigureFunction(PCB,0, PB0_MUX_PB0);
	HAL_GPIO_ConfigOutput(PCB, 0, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 0, DISABLE);	
	HAL_GPIO_SetPin(PB, _BIT(0));
	
	// Test Pin setting PB1
	HAL_GPIO_ConfigureFunction(PCB,1, PB1_MUX_PB1);
	HAL_GPIO_ConfigOutput(PCB, 1, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 1, DISABLE);	
	HAL_GPIO_SetPin(PB, _BIT(1));	

	// Test Pin setting PB2
	HAL_GPIO_ConfigureFunction(PCB,2, PB2_MUX_PB2);
	HAL_GPIO_ConfigOutput(PCB, 2, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 2, DISABLE);	
	HAL_GPIO_SetPin(PB, _BIT(2));	
	
	// external interrupt test pin PB7
	HAL_GPIO_ConfigureFunction(PCB, 7, PB7_MUX_PB7);
	HAL_GPIO_ConfigOutput(PCB, 7, INPUT);
	HAL_GPIO_ConfigPullup(PCB, 7, ENABLE);	

	// external interrupt test pin PB6
	HAL_GPIO_ConfigureFunction(PCB, 6, PB6_MUX_PB6);
	HAL_GPIO_ConfigOutput(PCB, 6, INPUT);
	HAL_GPIO_ConfigPullup(PCB, 6, ENABLE);	

 /* preemption = 1, sub-priority = 1 */
   NVIC_SetPriority(GPIOBE_IRQn, ((0x01<<1)|0x01));	
   NVIC_SetPriority(GPIOBO_IRQn, ((0x01<<1)|0x01));		
}

/**********************************************************************
 * @brief		EXTI_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void EXTI_Configure(void)
{
	uint8_t val_level_or_edge, mode;
	
  /* external interrupt clock setting*/
	HAL_SCU_MiscClockConfig(4,PBD_TYPE,CLKSRC_RING_OSC_1M,100);

	val_level_or_edge = IER_LEVEL;
	mode = 0x01; //low lever interrupt or falling edge interrupt mode
	HAL_GPIO_EXTI_Config(PCB, 6, val_level_or_edge, mode);
	HAL_GPIO_EXTI_Config(PCB, 7, val_level_or_edge, mode);
	
	NVIC_EnableIRQ(GPIOBE_IRQn);
	NVIC_EnableIRQ(GPIOBO_IRQn);
}


/**********************************************************************
 * @brief		GPIO_ExitIntRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_ExitIntRun(void)
{				
		delay();
		HAL_GPIO_SetPin(PB, _BIT(2));
		delay();
		HAL_GPIO_ClearPin(PB, _BIT(2));
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	GPIO_Configure();
	
	/*EXTI Configure*/
	EXTI_Configure();

	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1){
   /* Infinite loop */
		GPIO_ExitIntRun();		
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
