/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void GPIO_Configure(void);
void GPIO_InputRun(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
static	uint8_t pin;
static	PCU_Type *PCx;
static	GPIO_Type *Px;
	
static const uint8_t menu[] =
"************************************************\n\r"
"GPIO input demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" GPIO input test  \n\r"
"************************************************\n\r";


/* Public Function ------------------------------------------------------------*/
/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}


/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}


/**********************************************************************
 * @brief		delay
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void delay(void)
{
	uint32_t i;
	
	for (i = 0; i < 0x100000; i++) ;	
}


/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	// Test Pin setting PB0
	HAL_GPIO_ConfigOutput(PCB, 0, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 0, ENABLE);	
	HAL_GPIO_SetPin(PB, _BIT(0));
	
	/* Test Pin setting PA5*/
	PCx = PCA;
	Px = PA;
	pin = 5;

	HAL_GPIO_ConfigOutput(PCx, pin, INPUT);
	HAL_GPIO_ConfigPullup(PCx, pin, DISABLE);	
	HAL_GPIO_SetDebouncePin(PCx, pin,ENABLE);
	
}

/**********************************************************************
 * @brief		GPIO_MiscClockConfigure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_MiscClockConfigure(void)
{
	/*LSI=1MHz, N=100, 1MHz/100=10KHz */
	HAL_SCU_MiscClockConfig(4,PAD_TYPE,CLKSRC_RING_OSC_1M,100);  
}


/**********************************************************************
 * @brief		GPIO_InputRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_InputRun(void)
{				
	if (HAL_GPIO_ReadPin(Px) & (1<<pin))
		HAL_GPIO_SetPin(PB, _BIT(0));
	else 
		HAL_GPIO_ClearPin(PB, _BIT(0));
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	GPIO_Configure();
	
	/*EXTI Configure*/
	GPIO_MiscClockConfigure();

	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1)
	{
		/*GPIO Input Test start*/
		GPIO_InputRun();
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
