/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void SysTick_Handler_IT(void);
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void GPIO_Configure(void);
void SYSTICK_Configure(void);
void GPIO_LedBlinkyRun(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
static uint32_t MilliSec;
static uint8_t tmp = 0;

static const uint8_t menu[] =
"************************************************\n\r"
" GPIO demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" Using GPIO PB0,1 test \n\r"
"************************************************\n\r";

/* Public Function ------------------------------------------------------------*/
/*******************************************************************************
* @brief      SysTick interrupt handler @ 1000Hz(1ms)
* @param      None
* @return     None
*******************************************************************************/
void SysTick_Handler_IT(void) {
	if (MilliSec) {
		MilliSec--;
	}
}


/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}

/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}

/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	// Test Pin setting PB0
	HAL_GPIO_ConfigOutput(PCB, 0, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 0, ENABLE);	
	HAL_GPIO_SetPin(PB, _BIT(0));

	// Test Pin setting PB1
	HAL_GPIO_ConfigOutput(PCB, 1, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 1, ENABLE);
	HAL_GPIO_SetPin(PB, _BIT(1));
	
	PB->ODR = 0x3f;
}


/**********************************************************************
 * @brief		SYSTICK_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void SYSTICK_Configure(void)
{
	// Enable Interrupt for Sytick timer
	NVIC_SetPriority (SysTick_IRQn, 1);
	
	//	1msec interrupt 	
	SysTick_Config(SystemCoreClock/1000); 
}


/**********************************************************************
 * @brief		GPIO_LedBlinkyRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_LedBlinkyRun(void)
{			
	#if 0		
		/* PB0, PB1 port toggle */
		MilliSec = 500;
		while(MilliSec);
		HAL_GPIO_ClearPin(PB,_BIT(0));
		MilliSec = 500;
		while(MilliSec);
		HAL_GPIO_SetPin(PB,_BIT(0));
		if (tmp&0x1)
			HAL_GPIO_SetPin(PB,_BIT(1));
		else 
			HAL_GPIO_ClearPin(PB,_BIT(1));
		if (++tmp == 8) tmp = 0;
#else 
		MilliSec = 50;
		while(MilliSec);
		tmp++;
		PB->ODR = tmp;
		
		if (tmp==0x40) tmp=0;
		
#endif		
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	GPIO_Configure();

	/*SYSTICK Configure*/
	SYSTICK_Configure(); 
	
	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1)
	{
		/*GPIO LedBlinky Test start*/
		GPIO_LedBlinkyRun();
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
