/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void GPIO_Configure(void);
void MPWM_Configure(void);
void MPWM_Run(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
static	int	_prot0 = 0;
static	int	_prot1 = 0;

static char cmd;
static	char ch;
//static	uint8_t *c;
//static	uint8_t ff;
static	uint16_t dutyh;
static	uint16_t dutyl;
static	uint16_t delta=0x10;
static	int	trg;	
static	int	mode;
	
static const uint8_t menu[] =
"************************************************\n\r"
"Motor PWM interrupt demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" Using MPWM\n\r"
"************************************************\n\r";

/* Public Function ------------------------------------------------------------*/
/*******************************************************************************
* @brief      NMI interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void	NMI_Handler_IT(void)
{
	int	sts;
	
	sts = SCU->NMIR;
	if(sts & (1<<12)) { //BV_MP0PR0STS
		MP0->PSR0 = 0xCA80;
		_prot0+= 100;
	}
	if(sts & (1<<11)) { //BV_MP0PR1STS
		MP0->PSR1 = 0xAC80;
		_prot1+= 100;
	}
}

/*******************************************************************************
* @brief      Mpwm0 protection interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void	MPWM0PROT_IRQHandler_IT(void)
{
	MP0->PSR0 = 0xCA80;
	_prot0++;
}

/*******************************************************************************
* @brief      Mpwm0 overvoltage interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void	MPWM0OVV_IRQHandler_IT(void)
{
	MP0->PSR1 = 0xAC80;
	_prot1++;
}

/*******************************************************************************
* @brief      protection status check
* @param      None
* @return     None
*******************************************************************************/
void	check_prot(void)
{
	if(_prot0) {
		cprintf("(PROT0=%d)\r\n",_prot0);
		_prot0=0;
	}
	if(_prot1) {
		cprintf("(PROT1=%d)\r\n",_prot1);
		_prot1=0;
	}
}

/*******************************************************************************
* @brief      Mpwm0 interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void	MPWM0_IRQHandler_IT(void)
{
	int	irq;
	irq=MP0->SR;// & MP0IER;
	//MP0SR = 0xFF;	//irq;
	
	if(irq&(1<<7)) { //BV_PRDIF
		MP0->SR = (1<<7);
		PA->ODR^=(1<<7);		
	}
	if(irq&(1<<6)) { //BV_BOTIF
		MP0->SR = (1<<6);
		PA->ODR^=(1<<6);			
	}
	if(irq&(1<<5)) { //BV_WHIF
		MP0->SR = (1<<5);
		PA->ODR^=(1<<5);			
	}
	if(irq&(1<<4)) { //BV_VHIF
		MP0->SR = (1<<4);
		PA->ODR^=(1<<4);			
	}
	if(irq&(1<<3)) { //BV_UHIF
		MP0->SR = (1<<3);
		PA->ODR^=(1<<3);			
	}
	if(irq&(1<<2)) { //BV_WLIF
		MP0->SR = (1<<2);
		PA->ODR^=(1<<2);			
	}
	if(irq&(1<<1)) {  //BV_VLIF
		MP0->SR = (1<<1);
		PA->ODR^=(1<<1);			
	}
	if(irq&(1<<0)) { //BV_ULIF
		MP0->SR = (1<<0);
		PA->ODR^=(1<<0);			
	}
}

/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}

/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}

/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	// Test Pin setting PB0
	HAL_GPIO_ConfigOutput(PCB, 0, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 0, ENABLE);	
	HAL_GPIO_SetPin(PB, _BIT(0));

	// Test Pin setting PB1
	HAL_GPIO_ConfigOutput(PCB, 1, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 1, ENABLE);
	HAL_GPIO_SetPin(PB, _BIT(1));
	
	PB->ODR = 0x3f;
}


/**********************************************************************
 * @brief		MPWM_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void MPWM_Configure(void)
{
	HAL_SCU_MiscClockConfig(2,PWM0_TYPE,CLKSRC_MCLK,1); // select clock source 	PWM0 clock src = MCLK(48Mhz) / 1 = 48Mhz
	HAL_MPWM_Init(MP0);
	HAL_MPWM_Cmd(MP0,1,0,1,0,1, 1);	// MPWM mode reg setting
	
	dutyh=0x600;
	dutyl=0x300;
	HAL_MPWM_SetPeriod(MP0,0x1000);	
	HAL_MPWM_SetUDuty(MP0,dutyh,dutyl);
	HAL_MPWM_SetVDuty(MP0,dutyh,dutyl);
	HAL_MPWM_SetWDuty(MP0,dutyh,dutyl);	
	HAL_MPWM_SetDeadTime(MP0,1,0,0,10); // dead time setting 
	
	/* preemption = 1, sub-priority = 1 */
	NVIC_SetPriority(MPWM0_IRQn, ((0x01<<1)|0x01));
	/* Enable Interrupt for MPWM channel */
	NVIC_EnableIRQ(MPWM0_IRQn);
	
	/* preemption = 1, sub-priority = 1 */
	NVIC_SetPriority(MPWM0PROT_IRQn, ((0x01<<1)|0x01));
	/* Enable Interrupt for MPWM Protection */
	NVIC_EnableIRQ(MPWM0PROT_IRQn);
	
		/* preemption = 1, sub-priority = 1 */
	NVIC_SetPriority(MPWM0OVV_IRQn, ((0x01<<1)|0x01));
	/* Enable Interrupt for MPWM Overvoltage */
	NVIC_EnableIRQ(MPWM0OVV_IRQn);
	
	mode=0;	
}

/**********************************************************************
 * @brief		MPWM_Run
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void MPWM_Run(void)
{			
	#if 1
		_DBG("*");			
		getstring();
    
		if (InFlag) {
			_DBG("\n\r");
			cmd=InData[0];
      
			if(strncmp(InData,"test",4)==0) {
				_DBG("test ");
				if(strncmp(InData+5,"spi",3)==0) {
					_DBG("spi ");
					cprintf("\n\r");
				}					
				_DBG("\n\r");
			}
			else {
				switch(cmd) {
			case 'n':	//halt
						MP0->CR2 ^=0x80;
						cprintf("\r\nMP0->CR2=%04x",MP0->CR2 );
						break;
			case 'x':	//start
						MP0->CR2 ^=1;
						cprintf("\r\nMP0->CR2=%04x",MP0->CR2);
						break;	
			case 'i':	
						ch=_DG;
						switch(ch) {
						case '0':	MP0->IER^= 0x01;	break; //BV_ULIE
						case '1':	MP0->IER^= 0x02;	break; //BV_VLIE
						case '2':	MP0->IER^= 0x04;	break; //BV_WLIE
						case '3':	MP0->IER^= 0x08;	break; //BV_UHIE
						case '4':	MP0->IER^= 0x10;	break; //BV_VHIE
						case '5':	MP0->IER^= 0x20;	break; //BV_WHIE
						case '6':	MP0->IER^= 0x40;	break; //BV_BOTIE
						case '7':	MP0->IER^= 0x80;	break; //BV_PRDIE
						}
						cprintf("\r\nMP0->IER=%04x",MP0->IER);
						break;
			case 'q':	ch=_DG;
						switch(ch) {
						case '0': 	MP0->PSR0^= 0xCA01;	break;
						case '1': 	MP0->PSR0^= 0xCA02;	break;
						case '2': 	MP0->PSR0^= 0xCA04;	break;
						case '3': 	MP0->PSR0^= 0xCA08;	break;
						case '4': 	MP0->PSR0^= 0xCA10;	break;
						case '5': 	MP0->PSR0^= 0xCA20;	break;
						case '6': 	MP0->PSR0^= 0xCA80;	break;
						}
			case ' ':	cprintf("\r\nPB->IDR=%04X",PB->IDR);
                    cprintf(" MP0->PCR0=%08X",MP0->PCR0);
                    cprintf(" MP0->PSR0=%04X",MP0->PSR0);
						break;
			case '1':	delta=1;break;
			case '0':	delta=0x10;break;
			case 's':	if(++mode>3) mode=0;
						MP0->MR = (MP0->MR&~(3<<1))|(mode<<1);
						cprintf("(MCHMOD=%d)",mode);
						break;

			case 'u':	if(MP0->MR&0x0001) {
							MP0->MR&=~0x0001;
							cprintf("(Up-count Mode)");
						}
						else {
							MP0->MR|= 0x0001;
							cprintf("(Up-down Mode)");
						}
						break;						
			case '[':	dutyh-=delta;
						MP0->DUH= dutyh;
						MP0->DVH= dutyh;
						MP0->DWH= dutyh;
						cprintf("\r\n(MP0->MR=%04X) dutyh=%d",MP0->MR,dutyh);
						break;
			case ']':	dutyh+=delta;
						MP0->DUH= dutyh;
						MP0->DVH= dutyh;
						MP0->DWH= dutyh;
						cprintf("\r\n(MP0->MR=%04X) dutyh=%d",MP0->MR,dutyh);
						break;
			case '{':	dutyl-=delta;
						MP0->DUL= dutyl;
						MP0->DVL= dutyl;
						MP0->DWL= dutyl;
						cprintf("\r\n(MP0->MR=%04X) dutyl=%d",MP0->MR,dutyl);
						break;
			case '}':	dutyl+=delta;
						MP0->DUL= dutyl;
						MP0->DVL= dutyl;
						MP0->DWL= dutyl;
						cprintf("\r\n(MP0->MR=%04X) dutyl=%d",MP0->MR,dutyl);
						break;
			case ',':	trg-= delta;
						MP0->ATR1=trg;
						cprintf("\r\n(MP0->MR=%04X) trg=%05x",MP0->MR,trg);
						break;
			case '.':	trg+= delta;
						MP0->ATR1=trg;
						cprintf("\r\n(MP0->MR=%04X) trg=%05x",MP0->MR,trg);
						break;						
			case 'd':
						_DBG("\n\r");							
						break;
				}
			}
		}		
		else {
			_DBG("\n\r");
			InFlag=0;
			InCount=0;	
		}
#else 
		check_prot();
		ff=_DG_(c);
		
//		if (ff) 
		{
			if (*c > 0){
			switch(*c) {
				case 'n':	//halt
					MP0->CR2 ^=0x80;
					cprintf("\r\nMP0->CR2=%04x",MP0->CR2 );
					break;
				case 'x':	//start
					MP0->CR2 ^=1;
					cprintf("\r\nMP0->CR2=%04x",MP0->CR2);
					break;	
				case 'i':	
					ch=_DG;
					switch(ch) {
					case '0':	MP0->IER^= 0x01;	break; //BV_ULIE
					case '1':	MP0->IER^= 0x02;	break; //BV_VLIE
					case '2':	MP0->IER^= 0x04;	break; //BV_WLIE
					case '3':	MP0->IER^= 0x08;	break; //BV_UHIE
					case '4':	MP0->IER^= 0x10;	break; //BV_VHIE
					case '5':	MP0->IER^= 0x20;	break; //BV_WHIE
					case '6':	MP0->IER^= 0x40;	break; //BV_BOTIE
					case '7':	MP0->IER^= 0x80;	break; //BV_PRDIE
					}
					cprintf("\r\nMP0->IER=%04x",MP0->IER);
					break;
				case 'q':	ch=_DG;
					switch(ch) {
					case '0': 	MP0->PSR0^= 0xCA01;	break;
					case '1': 	MP0->PSR0^= 0xCA02;	break;
					case '2': 	MP0->PSR0^= 0xCA04;	break;
					case '3': 	MP0->PSR0^= 0xCA08;	break;
					case '4': 	MP0->PSR0^= 0xCA10;	break;
					case '5': 	MP0->PSR0^= 0xCA20;	break;
					case '6': 	MP0->PSR0^= 0xCA80;	break;
					}
				case ' ':	cprintf("\r\nPB->IDR=%04X, MP0->PCR0=%08X, MP0->PSR0=%04X",PB->IDR,MP0->PCR0,MP0->PSR0);
						break;
				case '1':	delta=1;break;
				case '0':	delta=0x10;break;
				case 's':	if(++mode>3) mode=0;
						MP0->MR = (MP0->MR&~(3<<1))|(mode<<1);
						cprintf("(MCHMOD=%d)",mode);
						break;

				case 'u':	if(MP0->MR&0x0001) {
							MP0->MR&=~0x0001;
							cprintf("(Up-count Mode)");
						}
						else {
							MP0->MR|= 0x0001;
							cprintf("(Up-down Mode)");
						}
						break;						
				case '[':	dutyh-=delta;
						MP0->DUH= dutyh;
						MP0->DVH= dutyh;
						MP0->DWH= dutyh;
						cprintf("\r\n(MP0->MR=%04X) dutyh=%d",MP0->MR,dutyh);
						break;
				case ']':	dutyh+=delta;
						MP0->DUH= dutyh;
						MP0->DVH= dutyh;
						MP0->DWH= dutyh;
						cprintf("\r\n(MP0->MR=%04X) dutyh=%d",MP0->MR,dutyh);
						break;
				case '{':	dutyl-=delta;
						MP0->DUL= dutyl;
						MP0->DVL= dutyl;
						MP0->DWL= dutyl;
						cprintf("\r\n(MP0->MR=%04X) dutyl=%d",MP0->MR,dutyl);
						break;
				case '}':	dutyl+=delta;
						MP0->DUL= dutyl;
						MP0->DVL= dutyl;
						MP0->DWL= dutyl;
						cprintf("\r\n(MP0->MR=%04X) dutyl=%d",MP0->MR,dutyl);
						break;
				case ',':	trg-= delta;
						MP0->ATR1=trg;
						cprintf("\r\n(MP0->MR=%04X) trg=%05x",MP0->MR,trg);
						break;
				case '.':	trg+= delta;
						MP0->ATR1=trg;
						cprintf("\r\n(MP0->MR=%04X) trg=%05x",MP0->MR,trg);
						break;						
				case 'd':
						_DBG("\n\r");							
						break;
				}
			}
		}
#endif		
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	GPIO_Configure();

	/*MPWM Configure*/
	MPWM_Configure(); 
	
	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1)
	{
		/*MPWM Test start*/
		MPWM_Run();
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
