/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
//#define TEST_SINGLE_POLLING // spi master polling : single data 
//#define TEST_SINGLE_INTERRUPT // spi master interrupt : single data 
//#define TEST_MULTI_INTERRUPT // spi master interrupt : multi data 10 bytes
#define TEST_MULTI_DMA_INTERRUPT // spi master dma : multi data 10 bytes

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void GPIO_Configure(void);
void SPI_Configure(void);
void SPI_MasterRun(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
#ifdef TEST_SINGLE_POLLING
static	uint32_t rxdata;
static	uint32_t tmp;
static	uint32_t i;
#endif
#ifdef TEST_SINGLE_INTERRUPT
static	uint32_t tmp;
static	uint32_t i;
#endif
#ifdef TEST_MULTI_INTERRUPT 
static uint32_t tmp;
static uint32_t i;
static uint32_t stat;
#endif
#ifdef TEST_MULTI_DMA_INTERRUPT
static uint32_t tmp;
static uint32_t i;
static uint32_t stat;
static DMAC_Ch_CFG_Type DMACSPI0Rx;
static DMAC_Ch_CFG_Type DMACSPI0Tx;
#endif	

static	SPI_CFG_Type SP0_config;

static const uint8_t menu[] =
"************************************************\n\r"
" SPI slave demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" SPI0 slave. for this test, it needs external Master device\n\r"
"************************************************\n\r";
/* Public Function ------------------------------------------------------------*/
#ifdef TEST_SINGLE_INTERRUPT // spi master interrupt : single data 
// for this test, MOSI and MISO must be connected.  

uint32_t fflag;
uint32_t rxdata, txdata;

/**********************************************************************
 * @brief		SPI0 interrupt handler
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void SPI0_IRQHandler_IT(void)
{
	uint32_t status;
	
	status = HAL_SPI_GetStatus(SP0);	
	if ( (status & SPI_STAT_TXBUF_EMPTY) && (HAL_SPI_GetControl(SP0) & SPI_INTCFG_TXIE)){ // tx buffer empty		
		HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_TXIE, DISABLE);
		HAL_SPI_Enable(SP0, DISABLE);  // SPI0 disable 		
		HAL_SPI_TransmitData(SP0, txdata);
		HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 		
	}
	
	if ( (status & SPI_STAT_RXBUF_READY) && (HAL_SPI_GetControl(SP0) & SPI_INTCFG_RXIE)){ // rx buffer full		
		rxdata = HAL_SPI_ReceiveData(SP0);
		fflag=1;
	}	
}
#endif

#ifdef TEST_MULTI_INTERRUPT // spi master interrupt : multi data 
// for this test, MOSI and MISO must be connected. 

uint32_t fflag;

uint32_t rxdata[10], txdata[10];
uint32_t cnt, cntrx;

/**********************************************************************
 * @brief		SPI0 interrupt handler
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void SPI0_IRQHandler_IT(void)
{
	uint32_t status;
	
	status = HAL_SPI_GetStatus(SP0);
	if ( (status & SPI_STAT_TXBUF_EMPTY) && (HAL_SPI_GetControl(SP0) & SPI_INTCFG_TXIE)){ // tx buffer empty		
		if (status & SPI_STAT_IDLE){
			HAL_SPI_Enable(SP0, DISABLE);  // SPI0 disable 			
			HAL_SPI_TransmitData(SP0, txdata[cnt]);	
			HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable		
			cnt++;
		}
		if (cnt==10){
			HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_TXIE, DISABLE); //TXIE disable
		}
	}
	
	if ( (status & SPI_STAT_RXBUF_READY) && (HAL_SPI_GetControl(SP0) & SPI_INTCFG_RXIE)){ // rx buffer full			
		rxdata[cntrx] = SP0->RDR;
		cntrx++;
		if (cntrx==10){
			fflag=1;
		}
	}
}
#endif

#ifdef TEST_MULTI_DMA_INTERRUPT // spi master dma : multi data 
// for this test, MOSI and MISO must be connected. 

uint32_t fflag;
uint8_t rxdata[10], txdata[10];
uint32_t cnt, cntrx;

/**********************************************************************
 * @brief		SPI0 interrupt handler
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void SPI0_IRQHandler_IT(void)
{
	uint32_t status;
	
	status=HAL_SPI_GetStatus(SP0);
	if ( (status & SPI_STAT_TXDMA_DONE) && (HAL_SPI_GetControl(SP0) & SPI_INTCFG_TXDIE)){ // tx dma done	
		HAL_SPI_ClearPending(SP0, SPI_STAT_TXDMA_DONE);
		HAL_DMAC_ChCmd(DC3, DISABLE);
		HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_TXDIE, DISABLE); // TXDIE interrupt disable 
	}
	
	if ( (status & SPI_STAT_RXDMA_DONE) && (HAL_SPI_GetControl(SP0) & SPI_INTCFG_RXDIE)){ // rx dma done		
		HAL_SPI_ClearPending(SP0, SPI_STAT_RXDMA_DONE);	
		HAL_DMAC_ChCmd(DC2, DISABLE);	
		HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_RXDIE, DISABLE); // RXDIE interrupt disable 	
		fflag=1;
	}
}
#endif

/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}

/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}

/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	// Test Pin setting SPI
	HAL_GPIO_ConfigureFunction(PCD,0,PD0_MUX_SS0);
	HAL_GPIO_ConfigOutput(PCD, 0, INPUT);
	HAL_GPIO_ConfigPullup(PCD, 0, ENABLE);	

	HAL_GPIO_ConfigureFunction(PCD,1,PD1_MUX_SCK0);
	HAL_GPIO_ConfigOutput(PCD, 1, INPUT);
	HAL_GPIO_ConfigPullup(PCD, 1, ENABLE);	
	
	HAL_GPIO_ConfigureFunction(PCD,2,PD2_MUX_MOSI0);
	HAL_GPIO_ConfigOutput(PCD, 2, INPUT);
	HAL_GPIO_ConfigPullup(PCD, 2, ENABLE);	
	
	HAL_GPIO_ConfigureFunction(PCD,3,PD3_MUX_MISO0);
	HAL_GPIO_ConfigOutput(PCD, 3, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCD, 3, DISABLE);	
}

/**********************************************************************
 * @brief		DMA_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void DMA_Configure(void)
{
#ifdef TEST_MULTI_DMA_INTERRUPT // spi master dma : multi data
	HAL_DMAC_Init();
#endif
}
/**********************************************************************
 * @brief		SPI_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void SPI_Configure(void)
{
#ifdef TEST_SINGLE_POLLING	// spi master polling mode
/* SPI0 enable */
	SP0_config.Databit = SPI_DS_8BITS;
	SP0_config.CPHA = SPI_CPHA_LO;
	SP0_config.CPOL = SPI_CPOL_LO;
	SP0_config.DataDir = SPI_MSB_FIRST;
	SP0_config.Mode = SPI_SLAVE_MODE;
	SP0_config.BaudRate = 2; // PCLK / (2+1) 
	
	HAL_SPI_Init(SP0, &SP0_config);
	HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 	

	_DBG_(" ");
	i=0x30;
#endif

#ifdef 	TEST_SINGLE_INTERRUPT 
/* SPI0 enable */
	SP0_config.Databit = SPI_DS_8BITS;
	SP0_config.CPHA = SPI_CPHA_LO;
	SP0_config.CPOL = SPI_CPOL_LO;
	SP0_config.DataDir = SPI_MSB_FIRST;
	SP0_config.Mode = SPI_SLAVE_MODE;
	SP0_config.BaudRate = 2; // PCLK / (2+1) 
	
	HAL_SPI_Init(SP0, &SP0_config);
	
	HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_RXIE, ENABLE); // rx interrupt enable 
	HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 

    /* preemption = 1, sub-priority = 1 */
    NVIC_SetPriority(SPI0_IRQn, ((0x01<<1)|0x01));		
	NVIC_EnableIRQ(SPI0_IRQn);
	
	_DBG_(" ");
	i=0x30;	
#endif

#ifdef TEST_MULTI_INTERRUPT // spi master interrupt : multi data 

/* SPI0 enable */
	SP0_config.Databit = SPI_DS_8BITS;
	SP0_config.CPHA = SPI_CPHA_LO;
	SP0_config.CPOL = SPI_CPOL_LO;
	SP0_config.DataDir = SPI_MSB_FIRST;
	SP0_config.Mode = SPI_SLAVE_MODE;
	SP0_config.BaudRate = 2; // PCLK / (2+1) 
	
	HAL_SPI_Init(SP0, &SP0_config);

	HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_RXIE, ENABLE); // rx interrupt enable 
	HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 

    /* preemption = 1, sub-priority = 1 */
  NVIC_SetPriority(SPI0_IRQn, ((0x01<<1)|0x01));		
	NVIC_EnableIRQ(SPI0_IRQn);

	__enable_irq();
	
	_DBG_(" ");
#endif
#ifdef TEST_MULTI_DMA_INTERRUPT // spi master dma : multi data 
	/* SPI0 enable */
	SP0_config.Databit = SPI_DS_8BITS;
	SP0_config.CPHA = SPI_CPHA_LO;
	SP0_config.CPOL = SPI_CPOL_LO;
	SP0_config.DataDir = SPI_MSB_FIRST;
	SP0_config.Mode = SPI_SLAVE_MODE;
	SP0_config.BaudRate = 2; // PCLK / (2+1) 
	
	HAL_SPI_Init(SP0, &SP0_config);;

	HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 

    /* preemption = 1, sub-priority = 1 */
    NVIC_SetPriority(SPI0_IRQn, ((0x01<<1)|0x01));		
	NVIC_EnableIRQ(SPI0_IRQn);
	
	_DBG_(" ");
#endif
}


/**********************************************************************
 * @brief		SPI_SlaveRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void SPI_SlaveRun(void)
{			
	
#ifdef TEST_SINGLE_POLLING	
while((HAL_SPI_GetStatus(SP0) & SPI_STAT_TXBUF_EMPTY) != SPI_STAT_TXBUF_EMPTY); // check tx buffer empty 
// in Mx064, master and slave of TX are different.
// when slave mode, TX has TX buffer and TX shift buffer. 
// for filling TX shift buffer, disable -> fill TX buffer -> enable(at this time, move TX buffer to TX shift buffer) 
		HAL_SPI_Enable(SP0, DISABLE);  // SPI0 disable 
		HAL_SPI_TransmitData(SP0, i);
		HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 	
		
		while((HAL_SPI_GetStatus(SP0) & SPI_STAT_RXBUF_READY) != SPI_STAT_RXBUF_READY); // check rx buffer full	
		rxdata = HAL_SPI_ReceiveData(SP0);
		_DBG(" rx ="); _DBH(rxdata);	_DBG("\n\r");	
	
		if (rxdata == i)
			HAL_GPIO_SetPin(PB, _BIT(0));
		else 
			HAL_GPIO_ClearPin(PB, _BIT(0));
		
		i++;
		if (i==0x3a) i=0x30;
		for (tmp=0;tmp <1000000; tmp++);	
#endif
		
#ifdef TEST_SINGLE_INTERRUPT
		txdata = i;
		fflag=0;
		HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_TXIE, ENABLE);

		while(fflag == 0); // check rx buffer full 
		_DBG(" rx ="); _DBH(rxdata);	_DBG("\n\r");	
		
		if (rxdata == i)
			HAL_GPIO_SetPin(PB, _BIT(0));
		else 
			HAL_GPIO_ClearPin(PB, _BIT(0));
		
		i++;
		if (i==0x3a) i=0x30;
		for (tmp=0;tmp <1000000; tmp++);	
#endif
		
#ifdef TEST_MULTI_INTERRUPT // spi master interrupt : multi data 
for(i=0;i<10;i++){
			txdata[i]=i+0x30;
			rxdata[i]=0;
		}
		cnt=0; cntrx=0;
		fflag=0;
		HAL_SPI_ConfigInterrupt(SP0, SPI_INTCFG_TXIE, ENABLE);

		while(fflag == 0); // check rx buffer full 

		stat=0;
		for (i=0;i<10;i++){
			_DBG(" rx ="); _DBH(rxdata[i]);	_DBG("\n\r");	
			if (rxdata[i] != txdata[i])
				stat=1;			
		}
		
		if (stat == 1)
			HAL_GPIO_SetPin(PB, _BIT(0));
		else 
			HAL_GPIO_ClearPin(PB, _BIT(0));
		
		for (tmp=0;tmp <1000000; tmp++);	
#endif		
		
#ifdef TEST_MULTI_DMA_INTERRUPT // spi master dma : multi data 		
		for(i=0;i<10;i++){
			txdata[i]=i+0x30;
			rxdata[i]=0;
		}
		DMACSPI0Rx.TransferCnt = 10;
		DMACSPI0Rx.PeriSel = DMAC_PERISEL_SPI0RX;		
		DMACSPI0Rx.TransferWidth = DMAC_WIDTH_BYTE;
		DMACSPI0Rx.Dir = DMAC_DIR_RX;	
		DMACSPI0Rx.PeriAddr = 0x40009000;			
		DMACSPI0Rx.MemAddr = (uint32_t)(&rxdata[0]);
		HAL_DMAC_Setup(DC2, &DMACSPI0Rx);

		HAL_DMAC_ChCmd(DC2, ENABLE);

		//first data set
		HAL_SPI_Enable(SP0, DISABLE);  // SPI0 disable 		
		HAL_SPI_TransmitData(SP0, txdata[0]);
		HAL_SPI_Enable(SP0, ENABLE);  // SPI0 enable 
		
		DMACSPI0Tx.TransferCnt = 9;
		DMACSPI0Tx.PeriSel = DMAC_PERISEL_SPI0TX;				
		DMACSPI0Tx.TransferWidth = DMAC_WIDTH_BYTE;
		DMACSPI0Tx.PeriAddr = 0x40009000;			
		DMACSPI0Tx.MemAddr = (uint32_t)(&txdata[1]);	
		HAL_DMAC_Setup(DC3, &DMACSPI0Tx);	
		
		fflag = 0;			
		HAL_SPI_ConfigInterrupt(SP0, (SPI_INTCFG_TXDIE | SPI_INTCFG_RXDIE), ENABLE); // TXDIE,RXDIE interrupt enable 
		HAL_DMAC_ChCmd(DC3, ENABLE);
		
		while(fflag == 0); // check rx buffer full 

		stat=0;
		for (i=0;i<10;i++){
			_DBG(" rx ="); _DBH(rxdata[i]);	_DBG("\n\r");	
			if (rxdata[i] != txdata[i])
				stat=1;			
		}
		
		if (stat == 1)
			HAL_GPIO_SetPin(PB, _BIT(0));
		else 
			HAL_GPIO_ClearPin(PB, _BIT(0));
		
		for (tmp=0;tmp <1000000; tmp++);	
#endif		
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	GPIO_Configure();

	/*SPI Configure*/
	SPI_Configure(); 
	
	/*DMA Configure*/
	DMA_Configure(); 
	
	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1)
	{
		/*SPI Slave Test start*/
	SPI_SlaveRun();
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
