/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"


/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void DEBUG_MenuPrint(void);
void DEBUG_Init(void);
void GPIO_Configure(void);
void TIMER_Configure(void);
void TIMER_CaptureRun(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
static const uint8_t menu[] =
"************************************************\n\r"
"Timer Capture demo \n\r"
"\t - MCU: AC33M4064 \n\r"
"\t - Core: ARM Cortex-M3 \n\r"
"\t - Communicate via: UART0 - 115200 bps \n\r"
" Using Timer 0 \n\r"
"************************************************\n\r";

static TIMER_CAPTURECFG_Type T0_Config;
static __IO	uint32_t count;
static __IO	uint32_t flag;
static __IO	uint32_t fflag;
static uint32_t i;

/* Public Function ------------------------------------------------------------*/
/*******************************************************************************
* @brief      TIMER0 interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void TIMER0_IRQHandler_IT(void)
{
	if ((HAL_TIMER_GetStatus(T0) & TIMER_SR_MFA) == TIMER_SR_MFA){
		HAL_TIMER_ClearStatus(T0, TIMER_SR_MFA);
		count++;
		if (count >= 1000){
			count = 0;
			if (flag==0){
				flag=1;
				HAL_GPIO_ClearPin(PB, _BIT(0));					
			}
			else {
				flag=0;
				HAL_GPIO_SetPin(PB, _BIT(0));
			}				
		}	
	}
}

/*******************************************************************************
* @brief      GPIOA even interrupt handler
* @param      None
* @return     None
*******************************************************************************/
void GPIOAE_IRQHandler_IT(void)
{
	uint32_t status;
	
	status = HAL_GPIO_EXTI_GetStatus(PCA);
	if(status & (3<<(6<<1)))
	{
		HAL_GPIO_EXTI_ClearPin(PCA, status & (3<<(6<<1)));
		if (fflag == 0){
			fflag=1;
		}
		else if (fflag ==1){
			fflag = 2;
		}
	}	
}

/**********************************************************************
 * @brief		 menu Print
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_MenuPrint(void)
{
	#ifdef _DEBUG_MSG
	_DBG(menu);
	#endif
}

/**********************************************************************
 * @brief		DEBUG_Init
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void DEBUG_Init(void)
{
	#ifdef _DEBUG_MSG
	debug_frmwrk_init();
	#endif
}

/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	// Test Pin setting PB0
	HAL_GPIO_ConfigOutput(PCB, 0, PUSH_PULL_OUTPUT);
	HAL_GPIO_ConfigPullup(PCB, 0, ENABLE);	
	HAL_GPIO_SetPin(PB, _BIT(0));

	// TnI pin config set if need	
	HAL_GPIO_ConfigureFunction(PCA, 6, PA6_MUX_T0IO);
	HAL_GPIO_ConfigOutput(PCA, 6, INPUT);
	HAL_GPIO_ConfigPullup(PCA, 6, ENABLE);
	
}


/**********************************************************************
 * @brief		TIMER_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void TIMER_Configure(void)
{
	T0_Config.CkSel = PCLK_2; // SystemPeriClock=48Mhz=PCLK  CLOCK_IN = PCLK/2=24Mhz 
	T0_Config.Prescaler = 23;    // TCLK = (CLOCK_IN / (PRS+1))  = 24Mhz / 24 = 1Mhz ->1us

	T0_Config.ClrMode=RISING_EGDE;
	T0_Config.AdcTrgEn=DISABLE;
	
	HAL_TIMER_Init(T0, CAPTURE_MODE, &T0_Config); // timer0 setting 
//	HAL_TIMER_ConfigInterrupt(T0, TIMER_INTCFG_OVIE, ENABLE);

//    /* preemption = 1, sub-priority = 1 */
//    NVIC_SetPriority(TIMER0_IRQn, ((0x01<<1)|0x01));
//	/* Enable Interrupt for TIMER0 channel */
//    NVIC_EnableIRQ(TIMER0_IRQn);

  NVIC_SetPriority(GPIOAE_IRQn, ((0x01<<1)|0x01));	
	HAL_GPIO_EXTI_Config(PCA, 6, IER_EDGE, 3); 	
	NVIC_EnableIRQ(GPIOAE_IRQn);
	
	fflag=0;
	
	HAL_TIMER_ClearCounter(T0);
	HAL_TIMER_Cmd(T0, ENABLE); // timer start
}


/**********************************************************************
 * @brief		TIMER_CaptureRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void TIMER_CaptureRun(void)
{			
_DBG("\n\r Wait Pulse! \n\r");
	
	HAL_GPIO_ClearPin(PB, _BIT(0));
	for (i=0;i<1000;i++);
	HAL_GPIO_SetPin(PB, _BIT(0));
	for (i=0;i<1000;i++);	
	for (i=0;i<1000;i++);	
	for (i=0;i<1000;i++);	
	for (i=0;i<1000;i++);	
	for (i=0;i<1000;i++);	
	for (i=0;i<1000;i++);		
	HAL_GPIO_ClearPin(PB, _BIT(0));
	for (i=0;i<1000;i++);
	HAL_GPIO_SetPin(PB, _BIT(0));
	
	while(1){
		switch(fflag){
			case 0:
				break;
			case 1:
				break;
			case 2:
				_DBG("capture value! \n\r");
				count = HAL_TIMER_GetCountValue(T0,1); 
				_DBG("GRA = "); _DBH16(count); _DBG_(" ");
				fflag=0;
				break;
		}
	}
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure menu prinf*/
	DEBUG_MenuPrint();
 
	/*Configure port peripheral*/
	GPIO_Configure();

	/*Configure timer peripheral*/
	TIMER_Configure(); 
	
	/* Enable IRQ Interrupts */
	__enable_irq();
	
	/*TIMER Capture Test start*/
	TIMER_CaptureRun();
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{

	 /* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Initialize Debug frame work through initializing UART port  */
	DEBUG_Init();		
	
	/* Infinite loop */
	mainloop();  


	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
