/**********************************************************************
* @file		AC33Mx064_SystemClock.c
* @brief	Contains all macro definitions and function prototypes
* 			support for PCU firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
/***********************************************************************
 *                          AC33Mx064 Device 
 *------------------------------------------------------------------------
 *    System Clock source       | PLL 
 *------------------------------------------------------------------------
 *    SYSCLK(MHz)               | 48MHz
 *------------------------------------------------------------------------
 *    HCLK(MHz) - Core Clock    | 48MHz
 *------------------------------------------------------------------------
  *   PCLK(MHz) - Peri Clock    | 48MHz
 *------------------------------------------------------------------------
*************************************************************************/
#include "main_conf.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/*#define USED_LSI	*/	/* SystemClock LSI 			: 1MHz   */
/*#define USED_MOSC*/  		/* SystemClock  HSE 		: 8MHz     */
#define USED_MOSCPLL 	/* SystemClock HSE PLL 	: 48MHz    */ 


/* Clock Out Selection ( Monitoring )*/
/*#define USED_CLKO*/
		
/* Private function prototypes -----------------------------------------------*/
void SystemClock_Config (void);
/* Private variables ---------------------------------------------------------*/


/**************************************************************************
 * @brief			Initialize default clock for AC33Mx064 Board
 * @param[in]		None
 * @return			None
 **************************************************************************/
void SystemClock_Config (void)
{
	uint32_t i;

 /*  LSI Clock Setting  1MHz */	
#ifdef USED_LSI			
	HAL_SCU_LSI_ClockConfig(LSIOSC_EN); /*LSIOSC_EN_DIV2, LSIOSC_EN_DIV4*/
	SystemCoreClock=100000; 	/*1MHz*/
	SystemPeriClock=100000; 	/*1MHz*/	
	
	for (i=0;i<10;i++);	
	
	HAL_SCU_SystemClockChange(SC_LSIOSC);
#endif 

	
/*  HSE Clock Setting  8Mhz */
#ifdef USED_MOSC	
	HAL_SCU_HSE_ClockConfig(EXOSC_EN);
	SystemCoreClock=8000000uL; /*8MHz*/
	SystemPeriClock=8000000uL; /*8MHz*/

	for (i=0;i<100;i++);	

	HAL_SCU_HSE_ClockMonitoring();
	HAL_SCU_SystemClockChange(SC_EXOSC);
#endif


/*  HSE PLL Clock Setting  48Mhz */
#ifdef USED_MOSCPLL
	
	HAL_SCU_HSE_ClockConfig(EXOSC_EN);

	for (i=0;i<100;i++);	

	HAL_SCU_HSE_ClockMonitoring();
	HAL_SCU_SystemClockChange(SC_EXOSC);
	
	if (HAL_SCU_PLL_ClockConfig(ENABLE,  
                                               PLLCON_BYPASS_PLL, 
	                                             PLLCON_FIN_DIV_2, 
	                                             PLLCON_M_12, //4*12=48Mhz  
	                                             PLLCON_N_1)==ERROR)
	{
		while(1);
	}

	// EOSC --> EOSCPLL
	HAL_SCU_SystemClockChange(SC_EXOSCPLL); /* EOSCPLL*/
	
	// AC33M4064 only!!!  MCLK fail enable 
	SCU->CMR &= ~(1<<15);
	
	SystemCoreClock=48000000uL; 	/*48MHz*/
	SystemPeriClock=48000000uL;  	/*48MHz*/
#endif

	
// flash memory controller
	FM->MR = 0x81;       // after changing 0x81 -> 0x28 in FMMR reg, flash access timing will be able to be set.
	FM->MR = 0x28;       // enter flash access timing changing mode
	FM->CFG = (0x7858<<16) | (2<<8);  //flash access cycles 	
	                              // flash access time cannot overflow 20Mhz.
	                              // ex) if MCLK=48Mhz, 
	                              //       48/1 = 48 (can't set no wait)
	                              //       48/2 = 24 (can't set 1 wait)
	                              //       48/3 = 16 (2 wait is ok)
	                              // so, 2 wait is possible.
	FM->MR = 0;	      // exit flash access timing --> normal mode		
	

/*	CLKO function setting. check PORT setting (PC9) */
#ifdef USED_CLKO
	HAL_SCU_ClockOutput(4,ENABLE); 
#else
	HAL_SCU_ClockOutput(4,DISABLE);
#endif
}


