/**********************************************************************
* @file		main.c
* @brief	Contains all macro definitions and function prototypes
* 			support for ADC firmware library
* @version	1.00
* @date		
* @author	ABOV PTS team
*
* Copyright(C) 2020, ABOV Semiconductor
* All rights reserved.
*
**********************************************************************/
#include "main_conf.h"

/* Private define ------------------------------------------------------------*/
//#define SET_CONST
#ifdef SET_CONST
const UART_CFG_Type UARTConfigStruct=
{
//	38400,
	115200,
	UART_DATABIT_8,
	UART_PARITY_NONE,
	UART_STOPBIT_1
};
#endif

/* Private typedef -----------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void GPIO_Configure(void);
void UART_PollingRun(void);
void mainloop(void);
int main (void);
void Error_Handler(void);

/* Private variables ---------------------------------------------------------*/
#ifndef SET_CONST
	UART_CFG_Type UARTConfigStruct;
#endif 
static uint8_t ch;	

/* Public Function ------------------------------------------------------------*/
/**********************************************************************
 * @brief		PCU_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void GPIO_Configure(void)
{
	//UART0 pin config setting in PCU
	HAL_GPIO_ConfigureFunction(PCC, 14, PC14_MUX_RXD0);
	HAL_GPIO_ConfigOutput(PCC, 14, INPUT);
	HAL_GPIO_ConfigPullup(PCC, 14, ENABLE);
	
	HAL_GPIO_ConfigureFunction(PCC, 15, PC15_MUX_TXD0);
	HAL_GPIO_ConfigOutput(PCC, 15, PUSH_PULL_OUTPUT);	
	HAL_GPIO_ConfigPullup(PCC, 15, ENABLE);	
}


/**********************************************************************
 * @brief		UART_Configure
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void UART_Configure(void)
{
	// default: 38400-8-N-1	
#ifndef SET_CONST
	HAL_UART_ConfigStructInit(&UARTConfigStruct);
#endif
	HAL_UART_Init(U0,(UART_CFG_Type *)(&UARTConfigStruct));
	
	__enable_irq();
	HAL_UART_Transmit(U0,(uint8_t *)"Polling test \n\r",15,BLOCKING);	
}

/**********************************************************************
 * @brief		UART_PollingRun
 * @param[in]	None
 * @return 	None
 **********************************************************************/
void UART_PollingRun(void)
{			
	HAL_UART_Receive(U0,&ch,1,BLOCKING);
	HAL_UART_Transmit(U0, &ch,1,BLOCKING);
	
	if (ch==0x0d) 
	{
		HAL_UART_Transmit(U0,(uint8_t *)"\n\r",2,BLOCKING);
	}
}


/**********************************************************************
 * @brief		Main loop
 * @param[in]	None
 * @return	None
 **********************************************************************/
void mainloop(void)
{
	/*Configure gpio peripheral*/
	GPIO_Configure();

	/*Configure uart peripheral*/
	UART_Configure();
	
	/* Enable IRQ Interrupts */
	__enable_irq();
	
	while(1)
	{
		/*UART Polling Test start*/
		UART_PollingRun();
	}
}

/**********************************************************************
 * @brief		Main program
 * @param[in]	None
 * @return	None
 **********************************************************************/
int main (void)
{
	/* Initialize all port */
	Port_Init(); 

	/* Configure the system clock to HSE 8 MHz */
	SystemClock_Config();
	
	/* Infinite loop */
	mainloop();  

	return (0);
}

/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the check_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: check_param error line source number
  * @retval : None
 **********************************************************************/
void Error_Handler(void)
{
    while (1)
    {
    }
}

#ifdef  USE_FULL_ASSERT
/**********************************************************************
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
 **********************************************************************/
void check_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

   /* Infinite loop */
   while (1)
   {
   }
}
#endif

/* --------------------------------- End Of File ------------------------------ */
